********************************************************************************
** 							Replication Files	   							  **
**						        Master						  		 		  **	
** 			   			 Thriving Beyond Borders?							  **
**.             Understanding Refugee Children's Life Outcomes   		      **
**												 							  **
********************************************************************************

capture log close
clear all
macro drop _all
set more off, permanently  
set scheme s1mono, permanently
set varabbrev on
set seed 12345
cls

/*******************************************************************************
					PART 1:  Prepare folder paths
*******************************************************************************/

global path "C:\Users\wb558768\Downloads\version1\wld_134\replication_materials"

* Programm paths: 
cd "$path"
global do       = "$path/code"
global log      = "$do/log"

* Data paths 
global dta       = "$path/data"
global dta_clean = "$path/data/clean"
global dta_raw   = "$path/data/raw"

* Out paths
global out       = "$path/output"
* Graphs
set scheme s2manual, permanently

/*******************************************************************************
					PART 2:  Load necessary packages
********************************************************************************/

sysdir set PLUS "$do/ado" 

* Install packages
		foreach package in psmatch2 lablist renvars {
			capture which `package'
            if _rc == 111	ssc install `package'
			
		}

	
/*******************************************************************************
					PART 3:  Create Database
********************************************************************************/

/* 01. Load and save raw data: 
		Saves de-identified raw datasets.  */
		
	do "$do/01_load_save_raw.do"

	
/* 02. General Data: 
		Label and clean up common information for the different levels 
		of observation (children, households and principal members).   */
		
	do "$do/02_general_data.do"

/* 03. Kids Data: 
		Labeling and cleaning information for surveyed children includes 
		measures of cognitive development and mental health.  
		* 03.1 Sociodemographic characteristics. */
		do "$do/03_kids_variables.do"
		
		* 03.2 Cognitive Development: Calculating the peabody test score
		do "$do/03_1_kids_peabody.do"
		
		* 03.3 Mental Health: Calculating Score calculation for different 
		* scales for the measurement of children's social-emotional and mental development. 
		do "$do/03_2_kids_mental_health.do"
		
/* 04. Household Data: 
		Processing of the information from the surveyed households and 
		calculation of wealth measures.  .  */
		do "$do/04_household_variables.do"
		
/* 05. Main Members Data: 
		Cleaning of the data of the main persons in the household  */
		do "$do/05_main_members_variables.do"
		
/* 06. Final Data: 
		Merging of information from the different levels of observation  */
		do "$do/06_merges.do"
		
		
/*******************************************************************************
					PART 4:  Tables and Figures
********************************************************************************/
* Creation of the tables and figures reported in the working paper. 
		do "$do/07_tables_figures.do"
		