********************************************************************************
** 						   Replication Package   							  **
**						 Loads and saves raw data			  		 		  **	
** 			   			 Thriving Beyond Borders?							  **
**.             Understanding Refugee Children's Life Outcomes   		      **
**												 							  **
********************************************************************************

*------------------------------------------------------------------------------*
* 1. Load data
*------------------------------------------------------------------------------*
{
* First Wave (Final base)
** Coded database
//Load
import excel using "$dta_raw/baseline_final_20230707.xlsx", clear     ///
first sheet(VenRedsKids_COD)
* Lower case
rename *, lower	
}


*------------------------------------------------------------------------------*
* 2. Cleaning sensitive information
*------------------------------------------------------------------------------*
{
* 2.1. The identifying variables of the persons are cleaned.
{
* Age (List_2)
label var edad "Age"
replace edad="." if edad=="No sabe/No responde" | edad=="NA" | edad=="NA FLUJO"
destring edad, replace

* Sex (list_4)
ren genero sexo
label var sexo "Sex at birth"
* Sex (List_4)
replace sexo="." if sexo=="90"
destring sexo, replace
label define lab1 1"Male" 2"Female" 3"Other" 4"Prefers not to answer"
label values sexo lab1


* Fecha nacimiento niño (hog_3)
ren hog_31v1719fechanacimien hog_3_1_day
ren hog_31v1718fechanacimien hog_3_1_month
ren hog_31v1717fechanacimien hog_3_1_year
label var hog_3_1_day "Child's birth: day"
label var hog_3_1_month "Child's birth: month"
label var hog_3_1_year "Child's birth: year"

* Fecha nacimiento adulto
ren hog_14cuáleseldíadenacim hog_3_2_day
ren hog_14hog_31cuálesmesde hog_3_2_month
ren hog_14hog_312cuálesaño hog_3_2_year
label var hog_3_2_day "Adult's birth: day"
label var hog_3_2_month "Adult's: month"
label var hog_3_2_year "Adult's birth: year"

* Date of birth (Hog_3)
foreach var of varlist hog_3_1_day hog_3_1_month hog_3_1_year hog_3_2_day    ///
hog_3_2_month hog_3_2_year {
replace `var'="." if `var'=="NA FLUJO"
replace `var'="." if `var'=="NS"
replace `var'="." if `var'=="No sabe/No Repsonde"
replace `var'="." if `var'=="No sabe/No responde"
replace `var'="." if `var'=="SIN FECHA"
destring `var', replace
}
* Create one date of birth for everyone (using question of date of birth)
local temp "day month year"
foreach i of local temp {
	gen hog_3_`i' = .
	replace hog_3_`i' = hog_3_1_`i'
	replace hog_3_`i' = hog_3_2_`i' if hog_3_`i'==.
}
label var hog_3_day "Date of birth: day"
label var hog_3_month "Date of birth: month"
label var hog_3_year "Date of birth: year"

// Date of birth 
gen hog_3 = mdy(hog_3_month, hog_3_day, hog_3_year)
label var hog_3 "Date of birth (mdy)"

gen birth_date = hog_3
label var birth_date "Date of birth"
format birth_date %td

* Relationship with household's head (list_3)
label var parentesco "Relation HH (String)"
	** We need to create a numeric variable for parentesco
	gen order_p=.
	replace order_p=0 if parentesco=="00. Miembro no pertenece al hogar"
	replace order_p=1 if parentesco=="01. Es el jefe o la jefe de hogar"     ///
	| parentesco=="01.  Es el jefe o la jefe de hogar"
	replace order_p=2 if parentesco=="02. Pareja, esposo(a), cónyuge,compañero(a)"
	replace order_p=3 if parentesco=="03. Hija(o), hijastra(o)"
	replace order_p=4 if parentesco=="04. Madre, padre, padrastro, madrastra"
	replace order_p=5 if parentesco=="05. Hermano(a), hermanastro(a)"
	replace order_p=6 if parentesco==" 06. Suegra(o)"
	replace order_p=7 if parentesco=="07. Yerno, nuera"
	replace order_p=9 if parentesco=="09. Sobrino(a)"
	replace order_p=10 if parentesco=="10. Otro pariente"
	replace order_p=11 if parentesco=="11. Empleado(a) del servicio doméstico"
	replace order_p=12 if parentesco=="12. Nieto/a"
	*Label values 
	label var order_p "Relation HH"
	label define lab2 1"Head of the household" 2"Partner, wife, husband"     ///
	3"Daughter/son, stepdaughter, stepson" 4"Mother, father, stepmother stepfather" ///
	5"Brother\sister" 6"Mother\father in law" 7"Son\daughter-in-law" 9"Nephew\niece" ///
	10"Other relative" 11"Domestic worker" 12"Grandchild"
	label values order_p lab2
	
* Household Nationality
ren hfv42hogar nacionalidad_hog
label var nacionalidad_hog "Household's nationality" 

** Parents Names (Hog_0.1-Hog_0.4)
rename hog_12v1379madrehog_1 mother_name
rename hog_13v1378padrehog_1 father_name 
label var mother_name "Mother's name"
label var father_name "Father's name"

** Household's economic responsible (Hog_1.4)
rename hog_14v1380responsabl eresp_name
label var eresp_name "Economic responsible's name"
rename hog_2v1410responsable hog_0_2
label var hog_0_2 "Household's economic responsible"

* Respondent's name (nc)
capture ren ncv149nombrecompletodel respondent_name
capture label var respondent_name "Main Caregiver/respondent name"

* Comuna/Neighborhood
ren cont_01v1626enquécomun comuna
replace comuna="." if comuna=="NA" | comuna=="NA FLUJO"
//Other neighborhood-comuna
ren cont_01v1627otracuál comuna_other

** Comuna/Neighborhood
gen num_comuna=.
replace num_comuna=1 if comuna=="1. Popular"
replace num_comuna=2 if comuna=="2. Santa Cruz"
replace num_comuna=3 if comuna=="3. Manrique"
replace num_comuna=4 if comuna=="4. Aranjuez"
replace num_comuna=5 if comuna=="5. Castilla"
replace num_comuna=6 if comuna=="6. Doce de Octubre"
replace num_comuna=7 if comuna=="7. Robledo"
replace num_comuna=8 if comuna=="8. Villa Hermosa"
replace num_comuna=9 if comuna=="9. Buenos Aires"
replace num_comuna=10 if comuna=="10. La Candelaria"
replace num_comuna=11 if comuna=="11. Laureles - Estadio"
replace num_comuna=12 if comuna=="12. La América"
replace num_comuna=13 if comuna=="13. San Javier"
replace num_comuna=14 if comuna=="14. El Poblado"
replace num_comuna=15 if comuna=="15. Guayabal"
replace num_comuna=16 if comuna=="16. Belén"
replace num_comuna=50 if comuna=="50. San Sebastián de Palmitas"
replace num_comuna=60 if comuna=="60. San Cristobal"
replace num_comuna=70 if comuna=="70. Altavista"
replace num_comuna=80 if comuna=="80. San Antonio de prado"
replace num_comuna=90 if comuna=="90. Santa Elena"
replace num_comuna=98 if comuna=="Otra"
replace num_comuna=99 if comuna=="Localidad Metropolitana"
replace num_comuna=999 if comuna=="No sabe/No responde"
}


* 2.2 Module: References
{
** Household contact information
* Neighborhood
ren cont_02v1628enquébarri cont_0 
ren cont_02v1629otrocuál cont_0o
label var cont_0 "Contact: Neighborhood"
label var cont_0o "Contact: Neighborhood, other"

* Adress (cont_2)
ren cont_2v1630confirmardirec cont_2
label var cont_2 "Contact: Adress"

* Facebook account (cont_3)
ren cont_3v1642cuentadeface cont_3
label var cont_3 "Contact: Facebook account"

* Cellphone number (cont_4)
ren cont_4v1631númerocelular cont_4
label var cont_4 "Contact: Cellphone number"

* Phone number (cont_5)
ren cont_5v1633númeroteléfono cont_5
ren cont_51v1632cuáleseln cont_51
ren cont_52v1634aquiénpert cont_52
ren cont_52v1635otrocuál cont_53
label var cont_5 "Contact: Has phone number"
label var cont_51 "Contact: Phone number"
label var cont_52 "Contact: Phone number owner"
label var cont_53 "Contact: Phone number owner, other"

* Other number (cont_6)
ren cont_6v1636sielnúmeroan cont_6
ren cont_61v1637cuáleseln cont_61
label var cont_6 "Contact: Other phone number - contact name"
label var cont_61 "Contact: Other phone number - number"

* Email adress (cont_7)
ren cont_7v1638cuéntaconcor cont_7
ren cont_71v1639cuáleselc cont_71
label var cont_7 "Contact: Has email account"
label var cont_71 "Contact: Email adrress"

* Other Email (cont_8)
ren cont_8v1640tienealgunao cont_8
ren cont_81v1641cuáleselc cont_81
label var cont_8 "Contact: Has other email adress"
label var cont_81 "Contact: Other email adress"

* Thinks will move to another municipality (cont_9)
ren cont_9v1649quisiéramoscon cont_9
ren cont_91v1643departamento cont_91
ren cont_91v1644departamento cont_92
label var cont_9 "Contact: Thinks will move to another place"
label var cont_91 "Contact: Thinks will move to another Department"
label var cont_92 "Thinks will move to another Municipality"

* Thinks will move to another neighborhood (cont_10)
ren cont_91v1645departamento cont_10
label var cont_10 "Contact: Thinks will move to another neighborhood"
label var cont_10 "Thinks will move to another Neighborhood"

** Alternative contact info 
* Nombre
ren cont_93v1650contacto1c cont_12_1
ren cont_95v1661contacto2c cont_12_2
ren cont_97v1671contacto3c cont_12_3 
label var cont_12_1 "Contact #1: name"
label var cont_12_2 "Contact #2: name"	 
label var cont_12_3 "Contact #3: name"
	 
* Relationship
ren cont_93v1651contacto1c cont_13_1
ren cont_95v1662contacto2c cont_13_2
ren cont_97v1672contacto3c cont_13_3
label var cont_13_1 "Contact #1: Relationship"
label var cont_13_2 "Contact #2: Relationship"	 
label var cont_13_3 "Contact #3: Relationship"
//Other
ren cont_93v1654otrocuál cont_13_11
ren cont_95v1663otrocuál cont_13_21
ren cont_97v1673otrocuál cont_13_31
label var cont_13_11 "Contact #1: Relationship, other"
label var cont_13_21 "Contact #2: Relationship, other"	 
label var cont_13_31 "Contact #3: Relationship, other"

* Contact resides in the same dwelling
ren cont_93v1652contacto1 cont_14_1
ren cont_95v1664contacto2 cont_14_2
ren cont_97v1674contacto3 cont_14_3
forvalues i=1(1)3{
  label var cont_14_`i' "Contact #`i': Resides in the same dwelling"
}

* Contact location (cont_15)
//Depto
ren cont_94v1655ubicación cont_15_11
ren cont_96v1665ubicación cont_15_21
ren cont_98v1675ubicación cont_15_31
//Mpio
ren cont_94v1656ubicación cont_15_12
ren cont_96v1666ubicación cont_15_22
ren cont_98v1676ubicación cont_15_32
//Barrio
ren cont_94v1657ubicación cont_15_13
ren cont_96v1667ubicación cont_15_23
ren cont_98v1677ubicación cont_15_33
forvalues i=1(1)3{
  label var cont_15_`i'1 "Contact #`i': Department"
  label var cont_15_`i'2 "Contact #`i': Municipality"
  label var cont_15_`i'3 "Contact #`i': Neighborhood"
}

* Contact phone number (cont_16)
ren cont_94v1658ubicación cont_16_1
ren cont_96v1668ubicación cont_16_2
ren cont_98v1678ubicación cont_16_3
forvalues i=1(1)3{
  label var cont_16_`i' "Contact #`i': Phone number"
} 

* Contact phone number, other (cont_17)
ren cont_94v1659ubicación cont_17_1
ren cont_96v1669ubicación cont_17_2
ren cont_98v1679ubicación cont_17_3
forvalues i=1(1)3{
  label var cont_16_`i' "Contact #`i': Phone number, other"
} 

* Contact email (cont_18)
ren cont_94v1660ubicación cont_18_1
ren cont_96v1670ubicación cont_18_2
ren cont_98v1680ubicación cont_18_3
forvalues i=1(1)3{
  label var cont_18_`i' "Contact #`i': Has email"
} 

* Observations
ren ov55observaciones observaciones
label var observaciones "Observaciones de los encuestadores"
}
}

*------------------------------------------------------------------------------*
* 3. Identify household members and surveyed individuals
*------------------------------------------------------------------------------*
{
* 3.1. Create unique identifiers for each household member
{
sort idfamilia nombre edad sexo birth_date
duplicates r idfamilia nombre edad sexo birth_date
duplicates tag idfamilia nombre edad sexo birth_date, gen (dtag)
quietly by idfamilia nombre edad sexo birth_date:  gen dup = cond(_N==1,0,_n)
drop if dup>1
drop dtag dup

sort  idfamilia nombre edad sexo birth_date
bys idfamilia: egen sequence=seq()
order idfamilia sequence
egen id=concat(idfamilia sequence)

order idfamilia id nombre sexo edad birth_date parentesco order_p            ///
nacionalidad_hog mother_name father_name eresp_name encuestadorpi

* Check if all observations have idfamilia
count if idfamilia == "."  // no obs
}

* 3.2. Identify main members and kids 
{
* Household size
gen person=1
bys idfamilia: egen hh_size= sum(person)

* Identify the first family member (usefull when we want stats bby household)
gen first = 0
bysort idfamilia: replace first = 1 if _n == 1
label var first "First household member"

* Identify children (5-17)
gen menor = 0
replace menor = 1 if edad >= 5 & edad < 18
label var menor "Children: =1 if has 5-17 years old"

* Identify age group (children vs teenagers)
capture drop group
//According to IQ report 
gen group = 0
replace group = 1 if edad >= 5  & edad <= 10
replace group = 2 if edad >= 11 & edad <= 17
label var group "Age group (5-10 = 1)"
label define g 1"5-10 yrs" 2"11-17 yrs"
label values group g


* Number of children in the household
bysort idfamilia: egen menores_hogar = total(menor)
label var menores_hogar "Number of children in the household"

* Identify surveyed children	
gen nino_enc = 0
replace nino_enc = 1 if 													///
	sdqcas1v231comportamiento!="90" & menor == 1 | sdqcas1v232comportamiento!="90"   & menor == 1  | 						///
	sdqcas1v233comportamiento!="90" & menor == 1
label var nino_enc "Identifies surveyed children (=1 if surveyed)"


* Identify total surveyed children
bysort idfamilia: egen tot_nin_enc = total(nino_enc)
label var tot_nin_enc "Number of surveyed children by household"

* Number of adults in the household 
gen adulto = 0
replace adulto = 1 if edad >= 18
bysort idfamilia: egen adultos_hogar = total(adulto)
label var adultos_hogar "Number of adults in the household"

* Identify and tag surveyed adults
* Generate a numeric variable for member type
replace rol="1" if rol=="Cuidador Principal"
replace rol="2" if rol=="Madre"
replace rol="3" if rol=="Padre"
replace rol="4" if rol=="Responsable Economico"
replace rol="." if rol=="NA FLUJO"
destring rol, replace
label define roles 1"Caregiver" 2"Mother" 3"Father" 4"Economic Responsible"
label values rol roles
label var rol "Adult's role"
	
* Main Caregiver (list_5)
rename hog_01v1325respondientec list_5
label var list_5 "Child's relationship to survey respondent"
replace list_5="1" if list_5=="01.Madre/madrastra"
replace list_5="2" if list_5=="02.Padre/padrastro"
replace list_5="3" if list_5=="03.abuelo/(a)"
replace list_5="4" if list_5=="04.Otro NO pariente que pertenece al hogar"
replace list_5="5" if list_5=="05.Otro pariente que NO pertenece al hogar"
replace list_5="6" if list_5=="06.Otro NO pariente que NO pertenece al hogar"
replace list_5="7" if list_5=="07. Tío/a"
replace list_5="8" if list_5=="08. Hermano/a"
replace list_5="9" if list_5=="09. Otro pariente que pertenece al hogar"
replace list_5="10" if list_5=="10. Otro pariente"
replace list_5="11" if list_5=="11. No tiene. Empleado(a) del servicio doméstico"
replace list_5="12" if list_5=="12. Pareja, esposo(a), cónyuge, compañero(a)"
replace list_5="13" if list_5=="13. Yerno, nuera"
label define lab3 1"Mother" 2"Father" 3"Grandparent" 4"Other-not related living in household" 5"Other relative not living in the household" 6"Other-not related not living in the household" 7"Aunt/uncle" 8"Sibling" 9"Other relative that lives in the household" 10"Other relative" 11"Not related - Domestic Service" 12"Husband/Partner/Couple" 13"Son/Daughter-in-law"
destring list_5, replace
label values list_5 lab3 

* Household's economic responsible (Hog_1.4)
replace hog_0_2="1" if hog_0_2=="01. Madre" | hog_0_2=="14. Madrastra"
replace hog_0_2="2" if hog_0_2=="02. Padre" | hog_0_2=="13. Padrastro"
replace hog_0_2="3" if hog_0_2=="03. abuelo" |  hog_0_2=="04. Abuela"
replace hog_0_2="97" if hog_0_2=="07. Tio" | hog_0_2=="08. Tia" | hog_0_2=="15. Cuñado" | hog_0_2=="16. Hermana" | hog_0_2=="17. Hermano" | hog_0_2=="18. Madrina" | hog_0_2=="18. Prima" | hog_0_2=="19. Primo" | hog_0_2=="21. Padre social" | hog_0_2=="22. Madre social"  |  hog_0_2=="Otro, ¿cuál?"
label define lab6 1"Mother" 2"Father" 3"Grandparent" 97"other"
destring hog_0_2, replace
label values hog_0_2 lab6

* Lives in the household (Hog_2)
ren hog_14resideenestehogar hog_2
label var hog_2 "Lives in the household"

replace hog_2="1" if hog_2=="Si"
replace hog_2="2" if hog_2=="No"
replace hog_2="." if hog_2=="NA FLUJO"
destring hog_2, replace
//Labels
label define lab22 1"Yes" 2"No"
label values hog_2 lab22

* Relation to HH (Hog_5)
* Parentesco
rename hog_14hog_5cuáleselparen hog_5
label var hog_5 "Relation to household head"
replace hog_5="." if hog_5=="90"
destring hog_5, replace

* Clean names
do "$do/00.1 Program to clean variables containing names.do"
clean_name nombre respondent_name mother_name father_name eresp_name
	
	* Identify Roles
	** Caregiver 
	* Household has at least one member with the role caregiver assigned, for 
	*		this question I don't use the name of the caregiver/respondent 
	*		because that one is complete
	gen careg=0
	replace careg = 1 if rol == 1
	replace careg = 1 if nombre == "beatriz adriana matos lopez"
	bysort idfamilia: egen h_has_careg=total(careg)
	** Mother
	* Assigned Role + relationship of respondent to child
	gen mother=0
	replace mother=1 if rol==2  
	replace mother=1 if list_5==1 & rol==1 & sexo==2
	* Lets explore how many households have a mother
	bysort idfamilia: egen h_has_mother=total(mother)
	tab h_has_mother if first==1
	* Lets explore households that apparently don't have a mother
	bysort idfamilia: gen resp=respondent_name if respondent_name!="na flujo"
	* Check if respondent is mother and match names
	bysort idfamilia (resp): gen resp1 =1 if resp!=""
	bysort idfamilia (resp1): replace resp = resp[1] if missing(resp)
	replace mother=1 if rol==1 & resp==nombre & list_5==1 & sexo==2
	// Match mother's name with nombre to find other mothers conditional 
	*		on the household not having a mother (check one by one)
	replace mother=1 if nombre==mother_name & h_has_mother==0 & ///
				mother_name!="na" & mother_name!="na flujo" & sexo==2
	drop h_has_mother
	// Fix households with more than one mother
	bysort idfamilia: egen h_has_mother=total(mother)
	tab h_has_mother if first==1
	*br idfamilia nombre edad rol role mother father careg eresp 
	*	respondent_name father_name mother_name edu_hog_1 edu_hog_2 if 
	*	h_has_mother==2
	drop if idfamilia=="10225" & _n==702 | _n==703	


	** Father 
	* Assigned Role + relationship of respondent to child
	gen father=0
	replace father=1 if rol==3 
	replace father=1 if list_5==2 & rol==1 & sexo==1
	* Lets explore how many households have a father
	bysort idfamilia: egen h_has_father=total(father)
	tab h_has_father if first==1
	* Lets explore households that apparently don't have a father
	*br idfamilia nombre edad father father_name rol if h_has_father==0 & ///
	*	father_name!="na" & father_name!="na flujo"
	* Check if respondent is father and match names
	replace father=1 if list_5==2 & resp==nombre & sexo==1
	* Match father's name with nombre to find other fathers conditional on 
	*	the household not having a father (check one by one)
	replace father=1 if nombre==father_name & h_has_father==0 & 			///
		father_name!="na" & father_name!="na flujo" & sexo==1
	drop h_has_father
	// Fix households with two fathers
	bysort idfamilia: egen h_has_father=total(father)
	tab h_has_father if first==1
	*br idfamilia nombre edad rol role mother father careg eresp 			///
	* respondent_name father_name mother_name if h_has_father==2
	replace nombre="andres felipe zabala" if nombre=="andre felipe zabala" 	///
		& idfamilia=="11683"
	replace father=0 if nombre!=father_name & idfamilia=="11683"
	replace nombre="victor emilio rivas contreras" if 						///
		nombre=="victor emilio rivas contreras"
	replace father=0 if nombre!=father_name & idfamilia=="22519"
	replace father=0 if nombre!="javier de jesus arboleda bedoya" & 		///
		idfamilia=="12084"
	drop h_has_father
	** Economic Responsible
	// Assigned rol + mother or father is the econ resp and caregiver
	gen eresp=0
	replace eresp=1 if rol==4 | mother==1 & hog_0_2==1 | father==1 & hog_0_2==2 
	// Lets explore how many households have en econ resp
	bysort idfamilia: egen h_has_eresp=total(eresp)
	tab h_has_eresp
	// Lets explore households that apparently don't have an eresp
	*br idfamilia nombre edad eresp eresp_name rol list_5 hog_0_2 if ///
	* 	h_has_eresp==0 & eresp_name!="na" & eresp_name!="na flujo"
	// It is possible that grandparent is caregiver and economic resp
	replace eresp=1 if eresp_name==nombre & hog_0_2==3 & list_5==3 & h_has_eresp==0
	drop h_has_eresp
	// Lets explore households that apparently don't have an eresp
	bysort idfamilia: egen h_has_eresp=total(eresp)
	// Lets explore households that apparently don't have a father
	*br idfamilia nombre edad eresp eresp_name rol list_5 hog_0_2 if ///
	* 	h_has_eresp==0 & eresp_name!="na" & eresp_name!="na flujo"
	// It is possible that other relative or person is the eresp
	replace eresp=1 if eresp_name==nombre & hog_0_2==97 & h_has_eresp==0
	// Lets explore households that apparently don't have an eresp
	drop h_has_eresp
	bysort idfamilia: egen h_has_eresp=total(eresp)
	*br idfamilia nombre edad eresp eresp_name rol list_5 hog_0_2 ///
	*	if h_has_eresp==0 //& eresp_name!="na" & eresp_name!="na flujo"
	tab h_has_eresp
	drop h_has_eresp
	// We need to fix one by one the names of households where there is an ///
		*	economic responsible but the role wasn't identifyed 
		* (this has to be done checking one by one)
	replace eresp_name="paula andrea londono acevedo" if 					///
		eresp_name=="paula andrea londoño acevedo"
	replace eresp=1 if nombre =="paula andrea londono acevedo" 
	replace eresp=1 if nombre =="jhon albeiro castaneda figueroa"
	replace eresp=1 if nombre =="luis andres londono chica"
	replace eresp=1 if nombre =="luz dary echeverry de munoz"
	replace eresp=1 if nombre =="adriana del socorro agudelo londono"
	replace eresp=1 if nombre =="velsi maria castano sanchez"
	replace eresp=1 if nombre =="luz arled londono velasquez"
	// Lets explore households that apparently don't have an eresp
	bysort idfamilia: egen h_has_eresp=total(eresp)
	*br idfamilia nombre edad respondent_name mother_name father_name ///
	* eresp eresp_name rol list_5 hog_0_2 if h_has_eresp==0 
	drop h_has_eresp
	
* Identify surveyed adults based on roles
gen adult_enc = 0
replace adult_enc = 1 if rol! = . & hog_2 != . & hog_5 != . | 				///
	careg  == 1 & hog_2!=. & hog_5!=. | 									///
	mother == 1 & hog_2!=. & hog_5!=. | 									///
	father == 1 | eresp==1 & hog_2!=. & hog_5!=.
label var adult_enc "Interviwed adult [=1]"

* Number of Surveyed adults in the Household
bysort idfamilia: egen num_adult_enc = total(adult_enc)
label var num_adult_enc "Number of surveyed adults in the household"

* Identifies parents of children for descriptives of parents
gen parent = 1 if (mother == 1 | father == 1 )
label var parent "Either mother or father of children"

gen careg_parent=1 if careg==1 & parent==1
replace careg_parent=0 if careg_parent==. 
bysort idfamilia: egen parent_careg = total(careg_parent)
}
}
*------------------------------------------------------------------------------*
* 4. Anonymise database
*------------------------------------------------------------------------------*
{
preserve
keep idfamilia id nombre sexo edad birth_date parentesco order_p             ///
nacionalidad_hog mother_name father_name eresp_name encuestadorpi cont_*
save "$dta_clean/Confidential_Information", replace
restore 

drop nombre birth_date mother_name father_name eresp_name cont_*

save "$dta_raw/VenReps_Kids_Raw_Wave_1", replace
}
