********************************************************************************
** 						   Replication Package   							  **
**						       General Data					  		 		  **	
** 			   			 Thriving Beyond Borders?							  **
**.             Understanding Refugee Children's Life Outcomes   		      **
**												 							  **
********************************************************************************

use "$dta_raw/VenReps_Kids_Raw_Wave_1", clear 

*------------------------------------------------------------------------------*
* 		1. General Characteristics			   
*------------------------------------------------------------------------------*
* Date of the survey
gen surv_day   = substr(fechapadresi, 9, 2)
gen surv_month =  substr(fechapadresi , 6, 2)
gen surv_year  = 2022
destring surv*, replace
gen surv_date  = mdy(surv_month, surv_day ,surv_year)
label var surv_date "Survey date"

* Age in years, days and months (using survey date)
// Months
gen dofb_month   = mofd(hog_3)
gen dosurv_month = mofd(surv_date)
gen age_months   = dosurv_month - dofb_month
label var age_months "Age in months"
// Years
gen dofb_years= yofd(hog_3)
gen dosurv_years= yofd(surv_date)
gen age = dosurv_years-dofb_years
label var age "Age in years"

* Sex
gen female=sexo==2

* Dummy sex variable
gen sex_dumm = 1 if sexo == 1
replace sex_dumm = 0 if sexo == 2

* Filter 8, filter_9 - Parents nationality 
rename hfv259estehogaresdena filtro_8_9
label var filtro_8_9 "Parents Nationality"

* Household's Nationality
// Household nationality complete info using parents nationality
replace nacionalidad_hog = "Hogar colombiano" if filtro_8_9=="Madre y padre Colombianos" & nacionalidad_hog=="NA FLUJO"
replace nacionalidad_hog = "Hogar venezolano" if filtro_8_9=="Madre y padre venezolanos" & nacionalidad_hog=="NA FLUJO"
// Create Numeric variable
gen filtro_0=.
replace filtro_0=1 if nacionalidad_hog == "Hogar colombiano"
replace filtro_0=2 if nacionalidad_hog == "Hogar venezolano"
label var filtro_0 "Household's nationality"
label define lab100 1"Colombian Household" 2"Veneuelan Household"
label values filtro_0 lab100

gen venezuelan = 1 if filtro_0 == 2
recode venezuelan  (. = 0)
label var venezuelan "Venezuelan household =1"
label define ven 0"Colombian" 1"Venezuelan"
label values venezuelan ven 

* Colombian category
gen col=1 if venezuelan==0
replace col=0 if venezuelan==1

* Has always lived in Colombia (Hog_13)
ren hog_134siemprehavividoenc hog_13
label var hog_13 "Has always lived in Colombia"
ren hog_131v1730v32siemp hog_13_1
label var hog_13_1  "Child has always lived in Colombia"
replace hog_13_1="1" if hog_13_1=="01. Si"
replace hog_13_1="2" if hog_13_1=="02. No"
replace hog_13_1="." if hog_13_1=="NA FLUJO"
destring hog_13 hog_13_1, replace
replace hog_13=. if hog_13==90

//One variable for adults and children
replace hog_13=hog_13_1 if hog_13==.
recode hog_13 (2=0)
label var hog_13 "Has always lived in Colombia =1"
* Country of birth (Hog_8)
//Adults
rename hog_14hog_8enquépaísnaci hog_8
label var hog_8   "Country of birth"
	//Other
	rename hog_14otrocuálhog_8en hog_8o
	label var hog_8o  "Country of birth - other"
destring hog_8, replace
replace hog_8=. if hog_8==90
label define lab8 1"Venezuela" 2"Colombia" 3"Other"
label values hog_8 lab8

*Children
ren hog_81v1722enquépaísn hog_8_1 //nacionalidad_nin
label var hog_8_1 "Child's nationality"
rename hog_81v1723otrocuá hog_8_1o
label var hog_8_1o "Child's nationality - Other"
replace hog_8_1="." if hog_8_1=="NA FLUJO"
destring hog_8_1, replace

* Nacionalidad niños
gen nacionalidad_nin=hog_8_1

* Country of birth (hog_8)
//One variable for adults and children
replace hog_8=2 if nacionalidad_nin=="Colombia"
replace hog_8=1 if nacionalidad_nin=="Venezuela"
replace hog_8=2 if hog_13==1 & hog_8==.



* Identify venezuelan people [=1]
gen ven=.
replace ven=1 if hog_8==1 | hog_13==0 & filtro_0==2 
replace ven=0 if hog_8==2 | hog_8==3 | hog_13==1 & filtro_0==1
label var ven "Was borned in Venezuela =1"
label define nac 1"Venezuelan" 0"Colombian"
label values ven nac

* Migration dates
* Date of Arrival (Hog_14) Adults
ren hog_144día hog_14_day
ren hog_144mes hog_14_month 
ren hog_144año hog_14_year
label var hog_14_day "Date of arrival: day"
label var hog_14_month "Date of arrival: month"
label var hog_14_year "Date of arrival: year"
* Date of Arrival (Hog_14) Children 
ren hog_141v1731llegócol hog_14_1_day
ren hog_141v1732llegócol hog_14_1_month 
ren hog_141v1733llegócol hog_14_1_year
label var hog_14_1_day "Child's Date of arrival: day"
label var hog_14_1_month "Child's Date of arrival: month"
label var hog_14_1_year "Child's Date of arrival: year"

// Adults
//Year
replace hog_14_year="." if hog_14_year=="NA FLUJO" | hog_14_year=="NA"
destring hog_14_year, replace
//Month
replace hog_14_month="." if hog_14_month=="NA FLUJO" | hog_14_month=="NA" | hog_14_month=="No sabe/No responde"
destring hog_14_month, replace
//Day
replace hog_14_day="." if hog_14_day=="NA FLUJO" | hog_14_day=="NA" | hog_14_day=="No sabe/No responde"
destring hog_14_day, replace
// Children
// Day
replace hog_14_1_day="." if hog_14_1_day=="NA" | hog_14_1_day=="NA FLUJO" |hog_14_1_day=="No sabe/No responde"
destring hog_14_1_day, replace
// Month
replace hog_14_1_month="." if hog_14_1_month=="NA" | hog_14_1_month=="NA FLUJO" |hog_14_1_month=="No sabe/No responde"
destring hog_14_1_month, replace
// Year
replace hog_14_1_year="." if hog_14_1_year=="NA" | hog_14_1_year=="NA FLUJO" |hog_14_1_year=="No sabe/No responde"
destring hog_14_1_year, replace

// Leave only one migration date to obtain descriptive stats
local temp "day month year"
foreach i of local temp {
	gen mig_`i'=.
	replace mig_`i'=hog_14_1_`i'
	replace mig_`i'=hog_14_`i' if mig_`i'==.
}
//Complete date
gen mig_date_mdy=mdy(mig_month, mig_day, mig_year)
label var mig_date_mdy "Migration date (month day year)"
// Year month date
gen mig_date_ym=ym(mig_year, mig_month) 
label var mig_date_ym "Migration date (month year)"

* Final date
//Days
gen final_day=31
gen final_month=12
gen final_year=2022
gen final_date_mdy=mdy(final_month, final_day, final_year)
gen final_date_ym=ym( final_year, final_month)
gen dfinal_month=mofd(final_date_mdy)
gen dfinal_year=yofd(final_date_mdy)
label var final_date_mdy 													///
	"Final date: 31 Dec 2022 (we use it to calculate time in col)"

	
* Time in Colombia
// Days
gen days_incol=final_date_mdy-mig_date_mdy
//Months
gen dofmig_months=mofd(mig_date_mdy)
gen months_incol= dfinal_month-dofmig_months
//Years
gen dofmig_years=yofd(mig_date_mdy)
gen years_incol= dfinal_year-dofmig_years
	* Recover information from dates that have no days
	//Months
	gen temp_months=final_date_ym-mig_date_ym
	replace months_incol=temp_months if months_incol==.
	// Years
	gen years_incol_decimals=(temp_months/12)
	gen temp_years1=floor(temp_months/12)
	replace years_incol=temp_years1 if years_incol==.
	label var years_incol "Years in Colombia"
	label var years_incol_decimals "Years in Colombia, dec"
	label var months_incol "Months in Colombia "
	label var years_incol "Days in Colombia"
	
drop temp_months temp_years final_day final_month final_year ///
	 dofmig_months dofmig_years dfinal_month 			///
	dfinal_year dofmig_months dofmig_years
* Age in Venezuela
gen edad_ven = edad - years_incol_decimals 
replace edad_ven = 0 if edad_ven<0


gen adult= 1 if edad>=18
replace adult= 0 if adult==.
bys idfamilia: egen tot_adult= sum(adult)

*------------------------------------------------------------------------------*
* 		2. Education Variables			   
*------------------------------------------------------------------------------*

* Can read and write (Educ_1)
ren educ_1v41niño1educ_11 educ_1 //Comparar con educ_1v41niño1educ_11item1sabele educ_11v43niño2educ_12item1sabel
label var educ_1 "Child: Can read and write"

* Alphabetism
replace educ_1="1" if educ_1=="01. Sí"
replace educ_1="2" if educ_1=="02. No"
replace educ_1="3" if educ_1=="888. No sabe/No responde"
replace educ_1="." if educ_1=="NA" | educ_1=="NA FLUJO"
destring educ_1, replace
label define lab_al 1"Yes" 2"No" 3"Doesn't know'"
label values educ_1 lab_al

* Attends school (Educ_2)
ren educ_1v42niño1educ_21 educ_2
label var educ_2 "Child: Attends school"

* Enrolled in school Educ_2
replace educ_2="1" if educ_2=="01. Sí"
replace educ_2="2" if educ_2=="02. No"
replace educ_2="." if educ_2=="90"
destring educ_2, replace

* Current level of education (Educ_3)
//Level
ren educ_3v59escolareduc_31 educ_3a 
label var educ_3a "Child: Current level of education"
ren educv508cuáleselañoo educ_3
label var educ_3 "Child: Current level of education"
ren educv5099otrocuálpa educ_3o
//Grade/year 
ren gv510grado educ_3_1
replace educ_3_1="." if educ_3_1=="NA FLUJO"
destring educ_3_1 , replace 
label var educ_3_1 "Child: Current year/grade"
ren educ_3v63escolareduc_31 educ_3_1a
label var educ_3_1a "Child: Current year/grade"

* (Ven) Attended educational institution (Educ_25.5)
ren educ_255v90venezuelait educ_25_5
label var educ_25_5 "Child: (Ven) Attended educational institution"
destring educ_25_5, replace
replace educ_25_5=. if educ_25_5==90
label define lab255 1"all school year" 2"most of the school year" 3"half of the school year" 4"a few months of the school year" 5"didn't attend'"
label values educ_25_5 lab255

* Highest level of education completed (Educ_26) 
ren educ_261v93gradoaltoed educ_26
label var educ_26 "Child: Highest level of education"
destring educ_26, replace
// Other 
ren educ_261v9412otrocuá educ_26o
label var educ_26o "Child: Highest level of education, other"

* (Ven) Attended to educational institution (Educ_26.6) 
ren educ_266v96Últimoeduc_2 educ_26_6
label var educ_26_6 "Child:(Ven) Attended to educational institution"
destring educ_26_6, replace
replace educ_26_6=. if educ_26_6==90
label define lab266 1"all school year" 2"most of the school year" 3"half of the school year" 4"a few months of the school year" 5"didn't attend'"
label values educ_26_6 lab266 

**********************************************
* 2.1 Identify Students
**********************************************

* Student (children)
gen student_nin=.
replace student_nin=1 if  educ_2==1 & nino_enc==1
replace student_nin=0 if  educ_2==2 & nino_enc==1
replace student_nin=0 if educ_3o=="NO ESTUDIA"  & nino_enc==1 |	 			///
	educ_3o=="Desescolarizado, a distancia a veces"  & nino_enc==1 | 		///
	educ_3o=="No esta escolarizado"  & nino_enc==1 | 						///
	educ_3o=="No esta escolarizada" | 										///
	educ_3o=="No escolarizado"  & nino_enc==1 | 							///
	educ_3o=="No Estudia"  & nino_enc==1 | 									///
	educ_3o=="no estudia"  & nino_enc==1 | 									///
	educ_3o=="EMPIEZA EL OTRO AÑO"  & nino_enc==1

* Student in Ven
* Student in ven: enrollment before migration Ven children
gen student_ven = .
	* For students in 2022
replace student_ven = 1 if inlist(educ_25_5, 1, 2, 3, 4) & filtro_0 == 2 	///
						   & nino_enc == 1
replace student_ven = 0 if inlist(educ_25_5, 5) & filtro_0 == 2 			///
						   & nino_enc == 1
	* For non-students 2022
replace student_ven = 1 if inlist(educ_26_6, 1, 2, 3, 4) & filtro_0 == 2 	///
						   & nino_enc == 1	
replace student_ven = 0 if inlist(educ_26_6, 5) & filtro_0 == 2 			///
						   & nino_enc == 1	
label var student_ven "(Ven) Children: Was enrrolled in school before migrating"

	* For enrollment statistics: 
	* Enrollment colombian children 2022
	gen enroll_col 	  = student_nin if filtro_0 == 1
	label var enroll_col "Colombian children enrolled in 2022"
	gen enroll_ven_t0 = student_ven if filtro_0 == 2 
	label var enroll_ven_t0 "Venezuelan children enrolled before migrating"	
	gen enroll_ven_pre = student_ven if filtro_0 == 2 & edad_ven>=5 
	label var enroll_ven_pre "Venexuelan children enrolled pre migration"
	gen enroll_ven_t1 = student_nin if filtro_0 == 2
	label var enroll_ven_t1 "Venezuelan children enrolled in 2022"	
	gen enroll_ven = educ_25_5
	recode enroll_ven ( 1 2 3 = 1) (4 5 = 0) (6 = .) 
	
	
********************************************
* 2.2.Level of Education
********************************************

*----------------------------------------*
* 2.2.1 For Students 
*----------------------------------------*
/*
Cods nivel educativo: 
01. . .Preescolar
02. . .Primaria
03. . .Secundaria
04. . .Bachillerato técnico
05. . .Estudios técnicos y/o tecnológicos
06. . .Universitario/Profesional 
07. . .Maestría
08. . .Doctorado
9. . .Otro ¿Cuál?______
99. . .NS
*/ 
* Highest level of education completed (Educ_3)
gen nivel_educ_e=. 
label var nivel_educ_e "Nivel educ alcanzado SI estudiante"

replace nivel_educ_e=1 if educ_3=="01. Preescolar" & student_nin==1 
replace nivel_educ_e=2 if educ_3=="02. Primaria" & student_nin==1
replace nivel_educ_e=3 if educ_3=="03. Secundaria" & student_nin==1
replace nivel_educ_e=4 if educ_3=="04. Bachillerato técnico" &  student_nin==1
replace nivel_educ_e=5 if educ_3=="05. Estudios técnicos y/o tecnológicos incompletos" & student_nin==1
replace nivel_educ_e=6 if educ_3=="06. Universitario/Profesional" & student_nin==1
replace nivel_educ_e=7 if educ_3=="07. Especialización" & student_nin==1
replace nivel_educ_e=8 if educ_3=="08. Maestría" & student_nin==1
replace nivel_educ_e=9 if educ_3=="09. Doctorado" & student_nin==1
replace nivel_educ_e=10 if educ_3=="9. Otro, ¿cuál?" & student_nin==1
replace nivel_educ_e=99 if educ_3=="99. No sabe/No responde" & student_nin==1
replace nivel_educ_e=. if educ_3=="NA FLUJO"

//Fix other category
replace nivel_educ_e=1 if educ_3o=="Kinder" | educ_3o=="Jardin" | educ_3o=="Guarderia" | educ_3o=="Transicion" | educ_3o=="Procesos Basicos" | educ_3o=="Procesos Básicos" 
replace nivel_educ_e=2 if educ_3o=="Aceleracion" | educ_3o=="Aceleración" |   educ_3o=="Cuarto y Quinto"
replace nivel_educ_e=3 if educ_3o=="Nivelación quinto y sexto"|    educ_3o=="Validación Septimo - Octavo" | educ_3o=="Validando"
replace nivel_educ_e=4 if educ_3o=="Bachiller" 

//Labels
label define lab422  0"None" 1"Pre-primary" 2"Primary" 3"Lower secondary education" 4"Upper secondary education" 5"Short cycle tertiary education" 6"Bachelor's or equivalente level" 7"certificate program" 8"Master's level" 9"Doctoral or equivalent level" 10"Other" 99"Does not know"
label values nivel_educ_e lab422

// Fix student variable
replace student_nin=0 if educ_3o=="No estudia" & nino_enc==1 |  educ_3o=="No aplica" & nino_enc==1 |  educ_3o=="Desescolarizado" & nino_enc==1 | educ_3o=="No esta estudiando ya es bachiller" & nino_enc==1

* Year/grade (students)
gen grado_educ_e=educ_3_1


*----------------------------------------*
* 2.2.2 For NOT Students
*----------------------------------------*
/*
Cods nivel educativo: 
0. . . Ninguno 
1. . . Primaria incompleta
2 . . .Primaria completa
3 . . .Secundaria incompleta
4 . . .Secundaria completa
5 . . .Estudios técnicos y/o tecnológicos incompletos 
6 . . .Estudios técnicos y/o tecnológicos completos
7 . . .Universitaria incompleta
8 . . .Universitaria completa
9 . . .Especialización
10 . . .Maestría
11 . . .Doctorado
12 . . .Otro. Cuál___

*/ 
* Highest level of education completed (Educ_26) 
/*
0. Ninguno	1
1. Primaria incompleta	2
12. Otro, ¿cuál?	3
2. Primaria completa	4
3. Secundaria incompleta	5
4. Secundaria completa	6
NA FLUJO	90
*/

destring educ_26, replace

gen nivel_educ_ne=. 
label var nivel_educ_ne "Nivel educ alcanzado NO estudiante"

//None
replace nivel_educ_ne=0 if educ_26==1 | educ_26==0 & student_nin==0  
//Primaria incompleta
replace nivel_educ_ne=1 if educ_26==2 & student_nin==0 
//Primaria completa 
replace nivel_educ_ne=2 if educ_26==4 & student_nin==0 
//Secundaria incompleta
replace nivel_educ_ne=3 if educ_26==5 & student_nin==0 
//Secundaria completa
replace nivel_educ_ne=4 if educ_26==6 & student_nin==0 
//Estudios técnicos y/o tecnológicos incompletos
replace nivel_educ_ne=5 if educ_26==7 & student_nin==0 
//Estudios técnicos y/o tecnológicos completos
replace nivel_educ_ne=6 if educ_26==6 & student_nin==0 
//Universitaria incompleta
replace nivel_educ_ne=7 if educ_26==7 & student_nin==0 
//Universitaria completa
replace nivel_educ_ne=8 if educ_26==8 & student_nin==0 
//Especialización
replace nivel_educ_ne=9 if educ_26==9 & student_nin==0 
//Maestría 
replace nivel_educ_ne=10 if educ_26==10 & student_nin==0 
//Doctorado
replace nivel_educ_ne=11 if educ_26==11 & student_nin==0 
//Other
replace nivel_educ_ne=12 if educ_26==3 & student_nin==0 
replace nivel_educ_ne=. if educ_26==90 & student_nin==0

//Fix other category
replace nivel_educ_ne=0 if educ_26o=="Preescolar" | educ_26o=="Prescolar"
replace nivel_educ_ne=1 if educ_3o=="No estudia, llego solo hasta 2 de primaria" 
replace nivel_educ_ne=6 if educ_3o=="Graduada" | educ_3o=="No esta estudiando ya es bachiller" 

// Lables
label define lab4444 0"None" 1"Incomplete Primary" 2"Complete primary" 3 "Incomplete secondary" 4"Complete secondary" 5"Incomplete short cycle tertiary education" 6"Complete short cycle tertiary education" 7"Incomplete bachelor's or equivalente level" 8"Complete bachelor's or equivalente level" 9"Specialization" 10"Master's level"  11"Doctoral level" 12"Other"
label values nivel_educ_ne lab4444

* Year/grade (not students - we didn't ask this question educ_26_1)
gen educ_26_1=.
gen grado_educ_ne=educ_26_1 if student_nin==0
*replace grado_educ_ne="0" if grado_educ_ne=="Ninguno"
*destring grado_educ_ne, replace


***********************************************
* 2.3 YEARS OF EDUCATION
***********************************************
gen educ_anos=.
*----------------------------------------*
* 2.3.1 Years of education for Students
* (if student==1)	
*----------------------------------------*
* Preescolar
replace educ_anos=0 if nivel_educ_e==1 & student_nin==1
replace educ_anos=. if edad<5 & student_nin==1 //Only surveyed children, 5 years or older

* Primaria 
replace educ_anos=grado_educ_e if nivel_educ_e==2 & edad!=grado_educ_e  & student_nin==1
// For children without year info
replace educ_anos=2.5 if nivel_educ_e==2 & grado_educ_e==. & student_nin==1 & educ_anos==.| nivel_educ_e==2 & grado_educ_e==0 & student_nin==1 & educ_anos==.

* Secundaria 
replace educ_anos=5+grado_educ_e if nivel_educ_e==3 & grado_educ_e<=5 & edad>10 & student_nin==1
replace educ_anos=grado_educ_e if nivel_educ_e==3 & grado_educ_e>5 & student_nin==1
replace educ_anos=8 if nivel_educ_e==3 & grado_educ_e==8 & student_nin==1
// For children without year info
replace educ_anos=7 if nivel_educ_e==3 & student_nin==1 & grado_educ_e==. & educ_anos==. | nivel_educ_e==3 & student_nin==1 & grado_educ_e==0 & educ_anos==. | nivel_educ_e==3 & educ_anos==. & student_nin==1 & edad==10
//br age educ_anos nivel_educ_e grado_educ_e if student_nin==1 & nivel_educ_e==3 & educ_anos==.

* Bachillerato tecnico 
replace educ_anos=9+grado_educ_e if nivel_educ_e==4 & student_nin==1 & grado_educ_e<10
replace educ_anos=grado_educ_e if nivel_educ_e==4 & student_nin==1 & grado_educ_e>=10
// For children without year info
replace educ_anos=10 if nivel_educ_e==4 & grado_educ_e==. | nivel_educ_e==4 & grado_educ_e==0 

* Técnico o tecnologico 
replace educ_anos=11+grado_educ_e if nivel_educ_e==5 & grado_educ_e<=3 & student_nin==1
replace educ_anos=11+(grado_educ_e*0.5) if nivel_educ_e==5 & grado_educ_e>3 & student_nin==1
// For children without year info
replace educ_anos=12.5 if nivel_educ_e==5 & student_nin==1 & grado_educ_e==. | nivel_educ_e==5 & student_nin==1 & grado_educ_e==0

* Universidad 
replace educ_anos=11+(grado_educ_e*0.5) if nivel_educ_e==6 & student_nin==1
replace educ_anos=13.5 if nivel_educ_e==6 & grado_educ_e==1	
// For children without year info
replace educ_anos=13.5 if  nivel_educ_e==6 & student_nin==1 & grado_educ_e==. | nivel_educ_e==6 & student_nin==1 & grado_educ_e==0

* Maestria 
replace educ_anos=16+(grado_educ_e*0.5) if nivel_educ_e==7 & grado_educ_e>=3 & student_nin==1 
// For children without year info
replace educ_anos=17 if  nivel_educ_e==7 & student_nin==1 & grado_educ_e==. | nivel_educ_e==7 & student_nin==1 & grado_educ_e==0

* Doctorado 
replace educ_anos=18+(grado_educ_e) if nivel_educ_e==8 & student_nin==1 	


*-------------------------------------------*
* 2.3.2 Years of Education for NOT Students
* (if student==0)	
*-------------------------------------------*	
* Ningun nivel de educacion
replace educ_anos=0 if nivel_educ_ne==0 & grado_educ_ne==0 & edad>=5 & educ_1!=1 & educ_1!=90 // sabe leer Y escribir
replace educ_anos=grado_educ_ne if nivel_educ_ne==0 & grado_educ_ne!=. & student_nin==0		
// For children without year info
replace educ_anos=0 if nivel_educ_ne==0 & grado_educ_ne==. & student_nin==0 
replace educ_anos=0 if nivel_educ_ne==0 & grado_educ_ne==. & student_nin==0 & educ_1!=1 & educ_1!=90
			

* Primaria incompleta 				
replace educ_anos=grado_educ_ne if nivel_educ_ne==1 & student_nin==0
// For children without year info
replace educ_anos=2.5 if nivel_educ_ne==1 & grado_educ_ne==. & student_nin==0   // & educ_1==1 //Promedio primaria 
replace educ_anos=2.5 if nivel_educ_ne==1 & grado_educ_ne==1 & student_nin==0 & educ_1==1   //Si, sabe leer Y escribir 

* Primaria completa
replace educ_anos=grado_educ_ne if nivel_educ_ne==2 & grado_educ_ne<5 & grado_educ_ne!=0 & student_nin==0
replace educ_anos=5 if grado_educ_ne==5 & nivel_educ_ne==2 & student_nin==0
replace educ_anos=grado_educ_ne if nivel_educ_ne==2 & grado_educ_ne>=6 & student_nin==0 
// For children without year info
replace educ_anos=5 if grado_educ_ne==. & nivel_educ_ne==2 & student_nin==0


* Secundaria incompleta 
replace educ_anos=5+grado_educ_ne if nivel_educ_ne==3 & grado_educ_ne<6 & student_nin==0		
replace educ_anos=grado_educ_ne if nivel_educ_ne==3 & grado_educ_ne>=7 & student_nin==0
replace educ_anos=7 if nivel_educ_ne==3 & grado_educ_ne==6 & edad<16 & student_nin==0		
replace educ_anos=11 if nivel_educ_ne==3 & grado_educ_ne==6 & edad>=16 & student_nin==0	
// For children without year info
replace educ_anos=8 if nivel_educ_ne==3 & grado_educ_ne==. & student_nin==0

* Secundaria completa 									
replace educ_anos=11 if nivel_educ_ne==4 & grado_educ_ne==0 & student_nin==0
replace educ_anos=11 if nivel_educ_ne==4 & grado_educ_ne==11 & student_nin==0
replace educ_anos=5+grado_educ_ne if nivel_educ_ne==4 & grado_educ_ne<=6 & grado_educ_ne!=0 & student_nin==0  
replace educ_anos=grado_educ_ne if nivel_educ_ne==4 & grado_educ_ne>6 & grado_educ_ne!=0 & student_nin==0
// For children without year info
replace educ_anos=11 if nivel_educ_ne==4 & grado_educ_ne==. & student_nin==0
		
* Tecnicos incompletos 
replace educ_anos=11 if nivel_educ_ne==5 & grado_educ_ne==0 & student_nin==0
replace educ_anos=11+grado_educ_ne if nivel_educ_ne==5 & grado_educ_ne<=3 & grado_educ_ne!=0  &  student_nin==0		
replace educ_anos=11+(grado_educ_ne*0.5) if nivel_educ_ne==5 & grado_educ_ne>3 &  grado_educ_ne<=6  &  student_nin==0	
replace educ_anos=grado_educ_ne if nivel_educ_ne==5 & grado_educ_ne>=10 & student_nin==0
// For children without year info
replace educ_anos=12.5 if nivel_educ_ne==5 & grado_educ_ne==. & student_nin==0
									
* Tecnicos completos 					
replace educ_anos=11+3 if nivel_educ_ne==6 & grado_educ_ne==0 & student_nin==0 & edad>16	
replace educ_anos=11+grado_educ_ne if nivel_educ_ne==6 & grado_educ_ne>0 &  grado_educ_ne<=3 &  student_nin==0	
replace educ_anos=11+(grado_educ_ne*.5) if nivel_educ_ne==6 & grado_educ_ne>3  &  grado_educ_ne<=6 & student_nin==0	
replace educ_anos=grado_educ_ne if nivel_educ_ne==6 & grado_educ_ne>=7 & student_nin==0
// For children without year info
replace educ_anos=15 if nivel_educ_ne==6 & grado_educ_ne==. & student_nin==0

* Universitarios 
replace educ_anos=11 if nivel_educ_ne==7 & grado_educ_ne==0 & student_nin==0
replace educ_anos=11+(grado_educ_ne*0.5) if nivel_educ_ne==7 & grado_educ_ne>0 & student_nin==0	
replace educ_anos=13 if nivel_educ_ne==7 & grado_educ_ne==. & student_nin==0

* Uni completa
replace educ_anos=16 if nivel_educ_ne==8 & student_nin==0

* Maestria 	
replace educ_anos=16+(0.5*grado_educ_ne) if nivel_educ_ne==9 & student_nin==0
replace educ_anos=18 if nivel_educ_ne==9 & grado_educ_ne==. & student_nin==0		

* Doctorado 					
replace educ_anos=18 if nivel_educ_ne==10 & student_nin==0
replace educ_anos=16+grado_educ_ne*0.5 if nivel_educ_ne==11  & student_nin==0 

*Strandarized years of education
		foreach i in educ_anos  {
			cap drop mean var r2 sd
			
			lpoly `i' edad if nino_enc==1, at(edad) gen(mean)	///
				  nograph
			gen r2=(`i'-mean)^2
			
			lpoly r2 edad if nino_enc==1, at(edad) gen(var) nograph
			gen sd=sqrt(var)
			gen `i'_std=(`i'-mean)/sd								
		}
		
*------------------------------------------------------------------------------*
* 		3. Access to services			   
*------------------------------------------------------------------------------*
* 3.1. SISBEN Access 
* Registered in SISBEN (t_1)
ren t_11estáregistradoenelsi t_1
label var t_1  "Registered in SISBEN"
ren dtv827transferenciast_1 t_1_1
label var t_1_1  "Main Caregiver Registered in SISBEN"

** Registered in SISBEN, child is included(t_2)
ren t_21eneseregistroestáincl t_2
label var t_2 "Registered in SISBEN, child is included?"
// Included in SISBEN since, month
ren t_211incluidoames t_21
label var t_21  "Included in SISBEN since, month"
// Registered in SISBEN since, year	
ren t_211incluidoaaño t_22
label var t_22  "Included in SISBEN since, year"

* Registered in SISBEN (t_1)
replace t_1="1" if t_1=="01. Si" | t_1=="01. Sí"
replace t_1="2" if t_1=="02. No"
replace t_1="3" if t_1=="03. No sabe/No repsonde"
replace t_1="." if t_1=="NA" | t_1=="NA FLUJO"
destring t_1, replace
lab define lab401 1"Yes" 2"No" 3"Doesn't know'"
label values t_1 lab401

** Registered in SISBEN, child is included(t_2)
replace t_2="1" if t_2=="01. Si"
replace t_2="2" if t_2=="02. No"
replace t_2="." if t_2=="NA" | t_2=="NA FLUJO"
destring t_2, replace
lab define lab41 1"Yes" 2"No"
label values t_2 lab41

* Adult has SISBEN
gen sisben=.
replace sisben=1 if t_1==1 & adult_enc==1
replace sisben=0 if t_1==2 & adult_enc==1 | t_1==3 & adult_enc==1

* Caregiver has SISBEN
cap drop temp 
cap drop sisben_careg
gen temp=1 if sisben==1 & careg==1
replace temp=0 if sisben==0 & careg==1
bys idfamilia: egen sisben_careg=max(temp)

* SISBEN includes the child
cap drop temp
gen temp=1 if t_2==1
replace temp=0 if t_2==2
bys idfamilia: egen sisben_nin=min(temp)  // En 1408 hogares hay niños cubiertos por el sisben


gen temp1 = 1 if t_2 == 1 
bys idfamilia: egen sisben_child = mean(temp1)
recode sisben_child ( . = 0)

// Colombians as base category
gen sisb=.
replace sisb=0 if col==1 & nino_enc==1 // Colombia
replace sisb=1 if ven==1 & sisben_child==1 // ven enrolled
replace sisb=2 if ven==1 & sisben_child==0 // not enrolled
// Dummies for regressions
gen sisb1 = (sisb==0)
gen sisb2 = (sisb==1)
gen sisb3 = (sisb==2)

* 3.2. Health Access 

*Affiliated to social security (salud_3)
ren salud_3v138enfermedadess  salud_3
label var salud_3 "Child: Social security health affiliate/beneficiary"
destring salud_3, replace
replace salud_3=. if salud_3==90
// Labels
label define lab130 1"Yes" 2"No" 3"NS/NR" 
label values salud_3 lab130

* Health before migrating (Salud_12)
ren salud_12v714segurosalud salud_12
label var salud_12 "(Ven) Child: Health inssurance before migrating"
replace salud_12="0" if salud_12=="90"
destring salud_12 , replace
label define salud12 1"Yes" 2"No"
label values salud_12 salud12

gen social_security = salud_3
recode social_security (2 = 0)

	* For descriptive statistics: Insurance by nationality/ prepost migration
	* 	of children
	gen insurance_col    = social_security if filtro_0 == 1 
	gen insurance_ven_t0 = .
	replace insurance_ven_t0 = 1 if salud_12 == 1 & filtro_0 == 2
	replace insurance_ven_t0 = 0 if salud_12 == 2 & filtro_0 == 2 	
	gen insurance_ven_t1 = social_security if filtro_0 == 2
	gen insurance_ven = 1 if salud_12 == 1
replace insurance_ven = 0 if salud_12 == 2
label var insurance_ven "Asegurado a salud en Vzla"

gen insurance = insurance_col 
*label var insurance "=1 if colombian hh counts with health insurance"
replace insurance = insurance_ven_t1 if venezuelan==1

gen health=.
replace health=0 if ven==0 & nino_enc==1  // Colombia
replace health=1 if ven==1 & nino_enc==1  & insurance==1 //ven enrolled
replace health=2 if ven==1 & nino_enc==1 & insurance==0 //not enrolled

// Dummies for regressions
gen health1 = (health==0)
gen health2 = (health==1)
gen health3 = (health==2)

* 3.3. School Enrollment 

* Education (School enrollment)
gen enrollment = educ_2
recode enrollment (2 = 0) 		
bys venezuelan: sum enrollment
// Colombians as base category
gen education=.
replace education=0 if ven==0 & nino_enc==1  // Colombia
replace education=1 if ven==1 & nino_enc==1  & enrollment==1 //ven enrolled
replace education=2 if ven==1 & nino_enc==1 & enrollment==0 //not enrolled
// Dummies for regressions
gen ed1 = (education==0)
gen ed2 = (education==1)
gen ed3 = (education==2)

gen enroll=enroll_col
replace enroll=1 if enroll_ven_t1==1
replace enroll=0 if enroll_ven_t1==0

bys idfamilia : egen total_enroll = max(enroll)

* 3.4. Regularization Access
// Adults
ren hog_202susituaciónmigrator hog_21
label var hog_21  "Regularized migratory status"
// Children
ren hog_201v1759regulaciónh hog_21_1
label var hog_21_1  "Children: Regularized migratory status"

* Regularized migratory status (hog_21)
// Adults
replace hog_21="." if hog_21=="NA" | hog_21=="NA FLUJO" | hog_21=="90"
destring hog_21, replace
label define lab16 1"Yes" 2"No" 3"NS/NR"
label values hog_21 lab16
// Children
replace hog_21_1="." if hog_21_1=="NA" | hog_21_1=="NA FLUJO"
replace hog_21_1="1" if hog_21_1=="01. Sí"
replace hog_21_1="2" if hog_21_1=="02. No"
replace hog_21_1="3" if hog_21_1=="99. No sabe/No responde"
destring hog_21_1, replace
label values hog_21_1 lab16

* Regularized
gen regularized=. 
replace regularized=hog_21_1
replace regularized=hog_21 if regularized==.
replace regularized=. if regularized==99 | regularized==90
label var regularized "Is regularized =1"
label define reg 1"regularized" 2"not regularized" 3"doesn't know'"
label values regularized reg
 
* Regular variable (new for determinants)
// Venezuelans only
gen regular = (hog_21 == 1) 
replace regular = 1 if hog_21_1 == 1 & venezuelan == 1
replace regular = . if venezuelan == 0
label define regul 1"Regular" 2"Not regular"
label values regular regul

* Children's parents regularized
gen temp4=0
replace temp4=1 if hog_21==1 & mother==1 | hog_21==1 & father==1
bys idfamilia: egen regular_parents = total(temp4)
replace regular_parents = . if venezuelan == 0
replace regular_parents = 1 if venezuelan == 1 & regular_parents==2
replace regular_parents = 0 if venezuelan == 1 & regular_parents==0
// Colombians as base category ()
gen categories=.
replace categories=0 if nino_enc==1 & ven==0 //Colombian
replace categories=1 if nino_enc==1 & ven==1 & regular_parents==1 //Regular
replace categories=2 if nino_enc==1 & ven==1 & regular_parents==0 //Irregular
// Dummies for regressions
gen regul1 = (categories==0)
gen regul2 = (categories==1)
gen regul3 = (categories==2)

drop temp*

save "$dta_clean/VenReps_General_Data", replace 
