********************************************************************************
** 						   Replication Package   							  **
**						      Kids Variables					  		 	  **	
** 			   			 Thriving Beyond Borders?							  **
**.             Understanding Refugee Children's Life Outcomes   		      **
**												 							  **
********************************************************************************

use "$dta_clean/VenReps_General_Data", clear

keep if nino_enc==1 

*------------------------------------------------------------------------------*
* 		1. Body Mass Index 			   
*------------------------------------------------------------------------------*

*************************************************
* 1.1. Antropometric measurements  
*************************************************
* Weight
ren d6v44adolescentese1pr salud_1_1
ren d6v45adolescentese2seg salud_1_2
ren d6v50adolescentese3ter salud_1_3
ren e3v48pesoacordadoprome salud_1
forvalues i=1(1)3 {
 label var salud_1_`i' "Weight #`i'"
}
label var salud_1 "Weight"

replace salud_1="." if salud_1=="NA FLUJO"
replace salud_1="." if salud_1=="No se tomó"
destring salud_1 , replace      

* Height 
ren d8v46adolescentesf1pri salud_2_1
ren d8v47adolescentesf2seg salud_2_2
ren d8v49adolescentesf3ter salud_2_3
ren f3v57tallaacordadaprom salud_2 
forvalues i=1(1)3 {
 label var salud_2_`i' "Height #`i'"
}
label var salud_2 "Height"

replace salud_2="." if salud_2=="NA FLUJO"
replace salud_2="." if salud_2=="No se tomó"
destring salud_2 , replace
*************************************************
* 1.2. Calculations
*************************************************
* Weight (Salud_1)
gen weight=salud_1
destring weight, replace

* Height (Salud_2)
gen height=salud_2
destring height, replace

* BMI (Weight/height2)
* Transform height so it is in m2 units
gen height2=height/100 

* Calculate BMI
gen bmi=.
replace bmi= (weight/(height2*height2))

* Calculate bmi Z-Score - Standarize (age in months)	
bys age_months: egen mean1=mean(bmi) if nino_enc==1 & group==1	
bys age_months: egen sd1=sd(bmi) if nino_enc==1 & group==1
gen bmi_std= (bmi-mean1)/sd1
drop mean1 sd1

* Calculate BMI standardized using Colombians as base group
// By age
bys age_months: egen mean1=mean(bmi) if nino_enc==1 & group==1 & ven==0	
bys age_months: egen sd1=sd(bmi) if nino_enc==1 & group==1 & ven==0	
gen bmi_stdm_col= (bmi-mean1)/sd1
drop mean1 sd1
// Full sample
egen mean1=mean(bmi) if nino_enc==1 & group==1 & ven==0	
egen sd1=sd(bmi) if nino_enc==1 & group==1 & ven==0	
gen bmi_std_col= (bmi-mean1)/sd1
drop mean1 sd1


* Merge WHO Z-scores table 
merge m:1 age_months sexo using "$dta/who/bmi-zscores-who"
drop if _merge==2
drop _merge

*************************************************
* 1.3. Categories
*************************************************

* Cut-off points (standarized var)
gen bmi_cat=.
replace bmi_cat=1 if bmi<SD2neg & bmi!=. & nino_enc==1 & group==1 //severe thinness
replace bmi_cat=2 if bmi>=SD2neg & bmi<SD1neg & nino_enc==1 & group==1  //thinness
replace bmi_cat=3 if bmi>=SD1neg & bmi<=SD1 & nino_enc==1 & group==1 //normal 
replace bmi_cat=4 if bmi>SD1 & bmi<=SD2 & nino_enc==1 & group==1 //overweight
replace bmi_cat=5 if bmi>SD2 & bmi!=. & nino_enc==1 & group==1 //obesity
label define bmi 1"severe thinness" 2"thinness" 3"normal" 4"overweight" 5"overweight"
label values bmi_cat bmi


* Dummies for weight category
tab bmi_cat if nino_enc==1 & group==1, g(bmi_)
ren (bmi_1 bmi_2 bmi_3 bmi_4 bmi_5) (bmi_severe_thin bmi_thinness bmi_normal bmi_overweight bmi_obese)

* Dummies for regressions
gen low_weight=.
replace low_weight=1 if bmi_severe_thin==1 | bmi_thinness==1
replace low_weight=0 if bmi_normal==1 | bmi_overweight==1 | bmi_obese==1
gen normal_weight=.
replace normal_weight=1 if bmi_normal==1
replace normal_weight=0 if bmi_severe_thin==1 | bmi_thinness==1| bmi_overweight==1 | bmi_obese==1
gen overweight=.
replace overweight=1 if bmi_overweight==1 | bmi_obese==1
replace overweight=0 if bmi_severe_thin==1 | bmi_thinness==1 |  bmi_normal==1 

* Sick last 30 days (salud_7a - 7d)
* Health issues in the last 30 days (salud_7)
ren salud_71v143hospitalizaci salud_7a
ren salud_71v144hospitalizaci salud_7b
ren salud_71v145hospitalizaci salud_7c
ren salud_71v146hospitalizaci salud_7d
ren salud_71v147hospitalizaci salud_7e
label var salud_7a "Child: Health issues in the last 30 days: Illnes or chronic pain"
label var salud_7b "Child: Health issues in the last 30 days: accident or physical injury"
label var salud_7c "Child: Health issues in the last 30 days: Dental problem"
label var salud_7d "Child: Health issues in the last 30 days: Ambulatory surgery"
label var salud_7e "Child: Health issues in the last 30 days: Pregnancy, postpartum or abortion complications" 
label define lab142 1"Yes" 2"No"
foreach var of varlist salud_7a salud_7b salud_7c salud_7d salud_7e {
 replace `var'="." if `var'=="90"
 destring `var', replace
 label values `var' lab142
}

gen sick_child = 1 if salud_7a==1 | salud_7b==1 | salud_7c==1 | salud_7d==1
replace sick_child = 0 if sick_child==.

*------------------------------------------------------------------------------*
* 		2. Social Cohesion	   
*------------------------------------------------------------------------------*

*************************************************
* 2.1. Altruism
*************************************************
ren alt_1v69situaciónalt_1 alt_1
label var alt_1 "Altruism"
replace alt_1="." if alt_1=="NA FLUJO"
destring alt_1, replace

gen alt_categories=.
replace alt_categories=1 if alt_1>=0 & alt_1<70000
replace alt_categories=2 if alt_1>=70000 & alt_1<140000
replace alt_categories=3 if alt_1>=140000 & alt_1<210000
replace alt_categories=4 if alt_1>=210000 & alt_1<280000
gen log_alt = log(alt_1)
*************************************************
* 2.2. Trust
*************************************************
ren b12v70expresionesconf_ conf_1
ren b12v71expresionesconf_ conf_2
ren b12v72expresionesconf_ conf_3
ren b12v73expresionesconf_ conf_4
ren b12v74expresionesconf_ conf_5
ren b12v75expresionesconf_ conf_6
label var conf_1 "Trust: When someone does me a favor, I am willing to"
label var conf_2 "Trust: If they treat me very unfairly, I will take revenge..."
label var conf_3 "Trust: You count on Colombians, even if you don't know them well"
label var conf_4 "Trust: I assume that people have the best intentions"
label var conf_5 "Trust: I am good at math"
label var conf_6 "Trust: I tend to postpone tasks, even when I know I should do them right away"

foreach var of varlist conf_1 conf_2 conf_3 conf_4 conf_5 conf_6 {
replace `var'="." if `var'=="90"   
destring `var', replace
}
* All questions need to be answered in the same direction fix this
recode conf_2 (0=10) (1=9) (2=8) (3=7) (4=6) (5=5) (6=4) (7=3) (8=2) (9=1) (10=0)

*************************************************
* 2.3. Identity
*************************************************
ren c12v76institucionesid_ id_1
ren c12v77institucionesid_ id_21
ren c12v78institucionesid_ id_22
ren c12v79institucionesid_ id_3
ren c12v80institucionesid_ id_4
label var id_1 "Identity: Thinks that most of the people can be trusted"
label var id_21 "Identity: Trusts in Colombian government"
label var id_22 "Identity: Trusts in Venezuelan government"
label var id_3 "Identity: Feels part of Colombian society"
label var id_4 "Identity: Feels part of the neighborhood or community where he/she lives"
foreach var of varlist id_1 id_21 id_22 id_3 id_4 {
    destring `var', replace
   replace `var'=. if `var'==90 
}

// id_1
label define labi1 1"most people can be trusted" 2"you need to be careful while interacting with most people"
label values id_1 labi1
// id_2 
label define labi2 1"fully trusts" 2"somewhat trusts" 3"doesn't trust" 4"doesn't trust at all"
label values id_21 labi2
label values id_22 labi2
// id_3 and id_4
label define labi34 1"a lot" 2"somewhat" 3"very little" 4"nothing"
label values id_3 labi34
label values id_4 labi34

* Identity items 
gen identity_1=id_1
recode identity_1 (2=0)

gen identity_21=id_21
recode identity_21 (4=0) (3=1) (2=3) (1=4)
replace identity_21=identity_21

gen identity_22=id_22
recode identity_22 (4=0) (3=1) (2=3) (1=4)

gen identity_3=id_3
recode identity_3 (4=0) (3=1) (2=3) (1=4)

gen identity_4=id_4
recode identity_4 (4=0) (3=1) (2=3) (1=4)

* Standarize 
foreach i in conf_1 conf_2 conf_3 conf_4 conf_5 conf_6 identity_1 identity_21 identity_3 identity_4 {

	sum `i' if venezuelan==0
	local mean = `r(mean)'
	local sd = `r(sd)'
	gen `i'_std=(`i'- `mean')/`sd'			
}
*************************************************
* 2.4. Others
*************************************************
* 2.4.1. Misstreatment 
* Has suffered abuse in the Ed. Inst.[=1] (educ_18)
ren educ_18v411maltratoinstit educ_18
label var educ_18 "Child: Has suffered abuse or misstreatment in the educational institution"
split educ_18, parse(";") generate(educ_18_)
label define lab188 1"None" 2"Physical abuse" 3"Verbal abuse" 4"Emotional abuse" 5"Doesn't know'"
forvalues i=1(1)3 {
label var educ_18_`i' "Child has suffered abuse in the Ed. Inst"
destring educ_18_`i', replace
replace educ_18_`i'=. if educ_18_`i'==90
label values educ_18_`i' lab188
}

gen miss_treat=1 if educ_18!="1" & educ_18!="90"
replace miss_treat=0 if educ_18=="1" | educ_18=="5"

* 2.4.2. Discrimination 
* Has suffered abuse in the Ed. Inst.[=1] (educ_19)
ren educ_19v80discriminacióni educ_19
label var educ_19 "Child 1:Has felt discriminated in the educational institution"
split educ_19, parse(";") generate(educ_19_)
label define lab_199 1"classmates" 2"teachers" 3"school authorities" 4"never"
forvalues i=1(1)3 {
label var educ_19_`i' "Child has suffered abuse in the Ed. Inst from"
destring educ_19_`i', replace
replace educ_19_`i'=. if educ_19_`i'==90
label values educ_19_`i' lab_199
}
gen discri=1 if educ_19!="4" & educ_19!="90"
replace discri=0 if educ_19=="4"

* 2.4.3. Friends 
* Number of friends in the educational institution(Educ_20)	
ren educ_20v81amigosniñosed educ_20
label var educ_20 "Child: Number of friends in the educational institution"
   
* Colombian/Ven friends in the educational institution (Educ_21)
 //Colombian
ren  educ_21v82amigoseduc_21 educ_21_1
label var educ_21_1 "Child: Number of Colombian friends in the educational institution" 
replace educ_21_1="." if educ_21_1=="NA" | educ_21_1=="NA FLUJO" | educ_21_1=="{VACIO}"  
//Venezuelan  
ren educ_21v83amigoseduc_21 educ_21_2
label var educ_21_2 "Child: Number of Venezuelan friends in the educational institution"
replace educ_21_2="." if educ_21_2=="NA" | educ_21_2=="NA FLUJO" | educ_21_2=="{VACIO}"  

destring educ_20, gen(friends)
replace friends=. if friends==90
replace educ_21_1="." if educ_21_1=="No sabe/No responde"
replace educ_21_2="." if educ_21_2=="No sabe/No responde"
destring educ_21_1, gen(friends_col)
destring educ_21_2, gen(friends_ven)

* 2.4.4. Time in Colombia 
* Cohort-groups by nationality
gen cohort = mig_year
recode cohort (2016 2017 = 1) (2018 2019 = 2) (2020 2021 = 3)
gen 	temp2 = 1 if venezuelan == 1 & cohort == 1
replace temp2 = 2 if venezuelan == 1 & cohort == 2
replace temp2 = 3 if venezuelan == 1 & cohort == 3
replace temp2 = 4 if venezuelan == 0 	
label define temp2 1"Mig 16-17" 2"Mig 18-19" 3"Mig 20-21"  4"Colombian" 
label values temp2 temp2

* Cohort groups by nationality in months
gen cohort_group=.
replace cohort_group=1 if months_incol<6 &  months_incol<12
replace cohort_group=2 if months_incol>=12 &  months_incol<=24
replace cohort_group=3 if months_incol>24 &  months_incol<=36
replace cohort_group=4 if months_incol>36 & months_incol<=48
replace cohort_group=5 if months_incol>48 & months_incol!=.
label define coh 1"Less than 1 year" 2"1-<2 years" 3"2-<3 years" 4"3-<4 years" 5"4 years or more"
label values cohort_group coh
	
* Time in Colombia dummies
	// Venezuelans only
	lablist cohort_group
	gen tiempo_col = 1 if inlist(cohort_group, 5)
	replace tiempo_col = 0 if inlist(cohort_group, 2, 3, 4)
	label define tiempo_col 1"4anos+" 0"menos 4 anos"
	label values tiempo_col tiempo_col 
	// Colombians as base category
	gen tiempo_col3 = 1 if inlist(cohort_group, 1, 2 , 3)
	replace tiempo_col3 = 2 if inlist(cohort_group, 4)
	replace tiempo_col3 = 3 if inlist(cohort_group, 5)
	replace tiempo_col3 = 0 if venezuelan == 0
	label define tiempo_col3 0"Colombian" 1"1-3 yrs" 2"3-4 yrs" 3"4+ yrs"
	label values tiempo_col3 tiempo_col3
	// Dummies for regressions
	gen tiempo1 = (tiempo_col3==1) 
	gen tiempo2 = (tiempo_col3==2)
	gen tiempo3 = (tiempo_col3==3)	

drop tiempo_col


keep if nino_enc==1



save "$dta_clean/VenReps_Kids_Variables", replace 




















