********************************************************************************
** 						   Replication Package   							  **
**						 Main Members Variables					  		 	  **	
** 			   			 Thriving Beyond Borders?							  **
**.             Understanding Refugee Children's Life Outcomes   		      **
**												 							  **
********************************************************************************
use "$dta_clean/VenReps_General_Data", clear

*------------------------------------------------------------------------------*
*			1. Adults: Sociodemographics    					   
*------------------------------------------------------------------------------*

* Marital status (Hog_7)
rename hog_14hog_7cuálessuestad hog_7
label var hog_7 "Marital status"
destring hog_7, replace
replace hog_7=. if hog_7==90
* Dummy marital status adults
gen married_adult = hog_7 == 3 
replace married_adult=1 if hog_7==2
label var married_adult "Adult: Marital status"

* Main occupation (Flab_204)
ren flab_204cuálessuocupación flab_204
label var flab_204  "Main occupation"
destring flab_204, replace
replace flab_204=. if flab_204==90
lab define lab24 1"Student" 2"Housewife" 3"Retired/Pensionary" 4"Unemployed" 5"Independent (professional)" 6"Employer" 7"Self-Employed" 8"Private sector employee" 9"Public sector employee" 10"Other"
label values flab_204 lab24
//Other
ren flab_2041otrocuálparaoc flab_204o
label var flab_204o  "Main occupation - other"
gen student_adult = flab_204 == 1 

* Health insurance adults 
ren hog_174estáafiliadoaesco hog_17
label var hog_17 "Social security health affiliate, beneficiary, etc"
destring hog_17, replace
replace hog_17=. if hog_17==90
label define lab13 3"Yes" 2"No" 1"NS/NR"
label values hog_17 lab13
gen health_adult = hog_17 == 3
label var health_adult "Adults: Health insurance"

* Labor Market 
** Main activity last week (Flab_205)
ren flab_205enquéactividadocu flab_205
label var flab_205  "Main activity last week"
destring flab_205, replace
replace flab_205=. if flab_205==90 
label define lab25 1"Working" 2"Looking for work" 3"Studying" 4"Doing housework" 5"Permanently disabled to work" 6"Other"
label values flab_205 lab25
//Other
ren flab_2051otraactividadcuá flab_205o
label var flab_205o  "Main activity last week - other"

* Last 4 weeks: looked for work (Flab_207)
ren flab_207enlasÚltimas4seman flab_207
label var flab_207 "Last week looked for work"
destring flab_207, replace
replace flab_207=. if flab_207==90 
label define lab270 1"Yes" 2"No"
label values flab_207 lab270

* If presented with job opportunity would take it (Flab_208)
ren flab_2081silehubieraresulta flab_208
label var flab_208 "If presented with job opportunity would take it"
destring flab_208, replace
replace flab_208=. if flab_208==90 
label define lab260 1"Yes" 2"No" 3"NS/NR"
label values flab_208 lab260

* Saving in pension fund (Ocu_216)
ren ocu_216estácotizandoactual ocu_216
label var ocu_216  "Saving in pension fund"
destring ocu_216, replace
replace ocu_216=. if ocu_216==90
lab define lab28 1"Yes" 2"No" 98"NS"
label values ocu_216 lab28

* Employment categories (Ocu_217)
ren ocu_217enestetrabajoes ocu_217
label var ocu_217  "Employment categories"
destring ocu_217, replace
replace ocu_217=. if ocu_217==90 
lab define lab29 1"Private firm employee" 2"Government employee" 3"Domestic worker" 4"Self-employed" 5"Employer" 6"Working for family business without remuneration" 7"Working for firm/business/household without remuneration" 8"Laborer" 9"NS/NR"
label values ocu_217 lab29

** Workers, unemplooyed, available to work 
gen labor_force = . 
replace labor_force = 1 if adult_enc == 1 & inlist(flab_205, 1, 2)
replace labor_force = 0 if adult_enc == 1 & inlist(flab_205, 3, 4, 5, 6)

* Employed
gen employed=.
replace employed = 0 if labor_force == 1 & flab_205 != 1 
replace employed = 1 if labor_force == 1 & flab_205 == 1

* Self-employed
	* Employer, working damily bussines, for firm without remuneration
gen self_employed = .
replace self_employed = 0 if employed == 1
replace self_employed = 1 if adult_enc == 1 & ocu_217 >= 4 & ocu_217 <= 7
** Unemployed
gen unemployed=.
replace unemployed = 1 if 													///
	labor_force == 1 & flab_205 == 2  | 									///
	labor_force == 1 & flab_207 == 1 & employed == 0 | 						///
	labor_force == 1 & flab_208 == 1 & employed == 0
replace unemployed = 0 if unemployed != 1 & labor_force == 1

* Informality [= 1 si no contribuye a pensíon y/o salud
gen informal=. 
replace informal = 0 if adult_enc == 1 & employed == 1
replace informal = 1 if adult_enc == 1 & employed == 1 & ocu_216==2 | 		///
	adult_enc == 1 & employed == 1 & hog_17 == 2
	
* Adult works with contract
ren ocu_213tienecontrato ocu_213
label var ocu_213 "Has work contract"
destring ocu_213, replace
replace ocu_213=. if ocu_213==90 
replace ocu_213=3 if ocu_213==4 //NS/NR
replace ocu_213=3 if ocu_213==5 //NS/NR
label define lab_cont 1"Verbal contract" 2"Written contract" 3"No contract"	98"NS/NR"
label values ocu_213 lab_cont
gen contract_adult = ocu_213 == 2
label var contract_adult "Adults: Has contract at work"


*------------------------------------------------------------------------------*
*			2. Adults: Education    					   
*------------------------------------------------------------------------------*
* Can read and write (Edu_hog_1)
ren edu_hog_1sabeleeryescribir edu_hog_1
label var edu_hog_1  "Respondent: Can read and write"
destring edu_hog_1, replace
replace edu_hog_1=. if edu_hog_1==90
//Labels
lab define lab200 1"Si" 2"No" 3"Doesn't know"
label values edu_hog_1 lab200

* Attends school/educational institution (Edu_hog_2) 
ren edu_hog_21actualmenteasiste edu_hog_2
label var edu_hog_2 "Respondent: Attends school/educational institution"
destring edu_hog_2, replace
replace edu_hog_2=. if edu_hog_2==90
//Labels
lab define lab20 1"Si" 2"No" 3"NS/NR"
label values edu_hog_2 lab20

* Current level education (Edu_hog_3)
ren edu_hog_31cuáleselañoogr edu_hog_3
label var edu_hog_3  "Current level of education"

* Grade year (Edu_hog_31)
ren edu_hog_311anotarnivelogra edu_hog_31
label var edu_hog_31  "Current grade/year"	

* Highest level of education completed (Edu_hog_4)
ren edu_hog_41cuáleselgradoed edu_hog_4
label var edu_hog_4  "Highest level of education"
	
* Grade year (Edu_hog_41)
ren edu_hog_411anotarnivelogra edu_hog_41
label var edu_hog_41 "Highest grade/year"

* Current level education (Edu_hog_3)
destring edu_hog_3, replace
replace edu_hog_3=. if edu_hog_3==90
// Grade year
replace edu_hog_31="." if edu_hog_31=="NA FLUJO"
replace edu_hog_31="98" if edu_hog_31=="No sabe/No responde" | edu_hog_31=="09. No sabe/ No responde"
destring edu_hog_31, replace

* Highest level of education completed (Edu_hog_4)
destring edu_hog_4, replace
replace edu_hog_4=. if edu_hog_4==90

* Student (Adults)
gen student=.
replace student=1 if edu_hog_2==1 & adult_enc==1
replace student=0 if edu_hog_2==2  & adult_enc==1 |  edu_hog_2==3  & adult_enc==1
label var student "Adult student"
** Para los que son estudiantes
/*
Cods nivel educativo: 
01. . .Preescolar
02. . .Primaria
03. . .Secundaria
04. . .Bachillerato técnico
05. . .Estudios técnicos y/o tecnológicos
06. . .Universitario/Profesional 
07. . .Maestría
08. . .Doctorado
9. . .Otro ¿Cuál?______
99. . .NS
*/ 


*******************************************************
* 2.1 Level of Education (Colombia)
*******************************************************

*----------------------------------------*
*  2.1.1 For Students
*----------------------------------------*

* Highest level of education completed (Edu_hog_3)
gen nivel_educ_adulte=. 
label var nivel_educ_adulte "Nivel educ alcanzado estudiante"

// None
replace nivel_educ_adulte=1 if edu_hog_3==0 & student==1 
// Primaria
replace nivel_educ_adulte=2 if edu_hog_3==1 & student==1 
// Secundaria 
replace nivel_educ_adulte=3 if edu_hog_3==2 & student==1 
// Bachillerato técnico
replace nivel_educ_adulte=4 if edu_hog_3==3 &  student==1 
// Estudios técnicos y/o tecnológicos 
replace nivel_educ_adulte=5 if edu_hog_3==4 & student==1 
// Universitario/Profesional
replace nivel_educ_adulte=6 if edu_hog_3==5 & student==1 
// Especialización
*replace nivel_educ_adulte=7 if edu_hog_3=="07. Especialización" & student==1
// Maestría
*replace nivel_educ_adulte=8 if edu_hog_3=="08. Maestría" & student==1
// Doctorado 
replace nivel_educ_adulte=9 if edu_hog_3==6 & student==1
// Other
*replace nivel_educ_adulte=10 if edu_hog_3=="9. Otro, ¿cuál?" & student==1
// Doesn't know
replace nivel_educ_adulte=99 if edu_hog_3==7 & student==1 //NS
replace nivel_educ_adulte=. if edu_hog_3==90 & student==1 | edu_hog_3==. & student==1

//Labels
label define lab42  0"None" 1"Pre-primary" 2"Primary" 3"Lower secondary education" 4"Upper secondary education" 5"Short cycle tertiary education" 6"Bachelor's or equivalente level" 7"certificate program" 8"Master's level" 9"Doctoral or equivalent level" 10"Other" 99"Does not know"
label values nivel_educ_adulte lab42

* Year/grade (students)
gen grado_educ_adulte=edu_hog_31
replace grado_educ_adulte=. if grado_educ_adulte==98


*----------------------------------------*
*  2.1.2 For non students
*----------------------------------------*
/*
Cods nivel educativo: 
0. . . Ninguno 
1. . . Primaria incompleta
2 . . .Primaria completa
3 . . .Secundaria incompleta
4 . . .Secundaria completa
5 . . .Estudios técnicos y/o tecnológicos incompletos 
6 . . .Estudios técnicos y/o tecnológicos completos
7 . . .Universitaria incompleta
8 . . .Universitaria completa
9 . . .Especialización
10 . . .Maestría
11 . . .Doctorado
12 . . .Otro. Cuál___

*/ 
* Highest level of education completed (edu_hog_4)
// Para los que NO son estudiantes 
destring edu_hog_4, replace
gen nivel_educ_adultne=. 
label var nivel_educ_adultne "Nivel educ alcanzado NO estudiante"
replace nivel_educ_adultne=0 if edu_hog_4==1 & student==0  //None
replace nivel_educ_adultne=1 if edu_hog_4==2 & student==0 //Primaria incompleta
replace nivel_educ_adultne=2 if edu_hog_4==3 & student==0 //Primaria completa
replace nivel_educ_adultne=3 if edu_hog_4==4 & student==0 //Secundaria incompleta
replace nivel_educ_adultne=4 if edu_hog_4==5 & student==0 //Secundaria completa
replace nivel_educ_adultne=5 if edu_hog_4==6 & student==0 //Estudios técnicos y/o tecnológicos incompletos
replace nivel_educ_adultne=6 if edu_hog_4==7 & student==0 //Estudios técnicos y/o tecnológicos completos
replace nivel_educ_adultne=7 if edu_hog_4==8 & student==0  //Universitaria incompleta
replace nivel_educ_adultne=8 if edu_hog_4==9 & student==0  //Universitaria completa
replace nivel_educ_adultne=9 if edu_hog_4==10 & student==0  // Especialización
replace nivel_educ_adultne=10 if edu_hog_4==11 & student==0 //Maestría
replace nivel_educ_adultne=11 if edu_hog_4==12 & student==0 //Doctorado
*replace nivel_educ_adultne=12 if edu_hog_4== & student==0 //Other
replace nivel_educ_adultne=. if edu_hog_4==13 & student==0  //NS/NR
replace nivel_educ_adultne=. if edu_hog_4==90 & student==0  //NA FLUJO

// Labels
label define lab444  0"None" 1"Incomplete Primary" 2"Complete primary" 3 "Incomplete secondary" 4"Complete secondary" 5"Incomplete short cycle tertiary education" 6"Complete short cycle tertiary education" 7"Incomplete bachelor's or equivalente level" 8"Complete bachelor's or equivalente level" 9"Specialization" 10"Master's level"  11"Doctoral level" 12"Other"
label values nivel_educ_adultne lab444

* Year/grade (not students)
gen grado_educ_adultne=edu_hog_41 if student==0 
replace grado_educ_adultne="." if grado_educ_adultne=="NA FLUJO" | grado_educ_adultne=="No sabe/No responde"
destring grado_educ_adultne, replace



******************************************************
* 2.2 Years of education (Colombia)
******************************************************
gen educ_anos_adult=.

*----------------------------------------*
* 2.2.1 Years of education for Students
* (if student==1)	
*----------------------------------------*
replace educ_anos_adult= 0 if student==1 
* Preescolar 
replace educ_anos_adult=0 if nivel_educ_adulte==1 & student==1
replace educ_anos_adult=. if age<5 & student==1

* Primaria 
replace educ_anos_adult=grado_educ_adulte if nivel_educ_adulte==2  & edad!=grado_educ_adulte  & student==1 
replace educ_anos_adult=2.5 if nivel_educ_adulte==2 & grado_educ_adulte==. & student==1

* Secundaria 
replace educ_anos_adult=5+grado_educ_adulte if nivel_educ_adulte==3 & grado_educ_adulte<=5 & edad>10 & student==1
replace educ_anos_adult=grado_educ_adulte if nivel_educ_adulte==3 & grado_educ_adulte>5 & student==1
replace educ_anos_adult=8 if nivel_educ_adulte==3 & edu_hog_31==98 | nivel_educ_adulte==2 & student==1 & educ_3_1==.

* Bachillerato tecnico 
replace educ_anos_adult=9+grado_educ_adulte if nivel_educ_adulte==4 & student==1 & grado_educ_adulte<10
replace educ_anos_adult=grado_educ_adulte if nivel_educ_adulte==4 & student==1 & grado_educ_adulte>=10
replace educ_anos_adult=8 if nivel_educ_adulte==4 & edu_hog_31==98 & student==1

* Técnico o tecnologico 
replace educ_anos_adult=11+grado_educ_adulte if nivel_educ_adulte==5 & grado_educ_adulte<=3 &  student==1
replace educ_anos_adult=11+(grado_educ_adulte*0.5) if nivel_educ_adulte==5 & grado_educ_adulte>3 & student==1
replace educ_anos_adult=12.5 if nivel_educ_adulte==5 & edu_hog_31==98 & student==1

* Universidad 
replace educ_anos_adult=11+(grado_educ_adulte*0.5) if nivel_educ_adulte==6 & student==1
replace educ_anos_adult=13.5 if nivel_educ_adulte==6 & edu_hog_31==.  & student==1 | nivel_educ_adulte==6 & edu_hog_31==98 & student==1

* Maestria 
replace educ_anos_adult=16+(grado_educ_adulte*0.5) if nivel_educ_adulte==7 & grado_educ_adulte>=3 & student==1 | nivel_educ_adulte==7 & edu_hog_31==98 & student==1

* Doctorado 
replace educ_anos_adult=18+(grado_educ_adulte) if nivel_educ_adulte==8 & student==1 
	

	
*------------------------------------------*
* 2.2.1 Years of education for NOT Students
* (if student==0)	
*------------------------------------------*
* Ningun nivel de educacion
replace educ_anos_adult=0 if nivel_educ_adultne==. & student==0 & edad>=5 
replace educ_anos_adult=0 if nivel_educ_adultne==0 & grado_educ_adultne==0 & edad>=5 & edu_hog_1!=1 & edu_hog_1!=. & student==0  //Si, sabe leer Y escribir 
replace educ_anos_adult=0 if nivel_educ_adultne==0 & grado_educ_adultne==. & student==0 & edu_hog_1!=1 & edu_hog_1!=.
replace educ_anos_adult=0 if nivel_educ_adultne==0 & grado_educ_adultne==0 & student==0	 		
replace educ_anos_adult=0 if nivel_educ_adultne==0 & grado_educ_adultne==. & student==0
replace educ_anos_adult=grado_educ_adultne if nivel_educ_adultne==0 & grado_educ_adultne!=. & student==0					

* Primaria incompleta 				
replace educ_anos_adult=grado_educ_adultne if nivel_educ_adultne==1 & student==0
replace educ_anos_adult=2.5 if nivel_educ_adultne==1 & grado_educ_adultne==. & student==0   		 // Promedio primaria 
replace educ_anos_adult=2.5 if nivel_educ_adultne==1  & grado_educ_adultne==0 & student==0 & edu_hog_1==1  //Si, sabe leer Y escribir 

* Primaria completa
replace educ_anos_adult=grado_educ_adultne if nivel_educ_adultne==2 & grado_educ_adultne<5 & grado_educ_adultne!=0 & student==0
replace educ_anos_adult=5 if grado_educ_adultne==5 & nivel_educ_adultne==2 & student==0
replace educ_anos_adult=grado_educ_adultne if nivel_educ_adultne==2 & grado_educ_adultne>=6 & 	student==0 
replace educ_anos_adult=5 if grado_educ_adultne==0 & nivel_educ_adultne==2 & student==0
replace educ_anos_adult=5 if grado_educ_adultne==. & nivel_educ_adultne==2 & student==0

* Secundaria incompleta 
replace educ_anos_adult=5+grado_educ_adultne if nivel_educ_adultne==3 & grado_educ_adultne<6 & student==0		
replace educ_anos_adult=grado_educ_adultne if nivel_educ_adultne==3 & grado_educ_adultne>=7 & student==0
replace educ_anos_adult=7 if nivel_educ_adultne==3 & grado_educ_adultne==6 & edad<16 &    student==0					
replace educ_anos_adult=11 if nivel_educ_adultne==3 & grado_educ_adultne==6 & edad>=16 & student==0	
replace educ_anos_adult=8 if nivel_educ_adultne==3 & grado_educ_adultne==. & student==0

* Secundaria completa 										
replace educ_anos_adult=11 if nivel_educ_adultne==4 & grado_educ_adultne==0 & student==0	
replace educ_anos_adult=11 if nivel_educ_adultne==4 & grado_educ_adultne==11 & student==0
replace educ_anos_adult=5+grado_educ_adultne if nivel_educ_adultne==4 & grado_educ_adultne<=6 & grado_educ_adultne!=0 & student==0  
replace educ_anos_adult=grado_educ_adultne if nivel_educ_adultne==4 & grado_educ_adultne>6 & grado_educ_adultne!=0 & student==0
					
* Tecnicos incompletos 
replace educ_anos_adult=11 if nivel_educ_adultne==5 & grado_educ_adultne==0 & student==0
replace educ_anos_adult=11+grado_educ_adultne if nivel_educ_adultne==5 & grado_educ_adultne<=3 & grado_educ_adultne!=0  &  student==0		
replace educ_anos_adult=11+(grado_educ_adultne*0.5) if nivel_educ_adultne==5 & grado_educ_adultne>3  &  grado_educ_adultne<=6  &  student==0	
replace educ_anos_adult=grado_educ_adultne if nivel_educ_adultne==5 & grado_educ_adultne>=10 & student==0
replace educ_anos_adult=12.5 if nivel_educ_adultne==5 & grado_educ_adultne==. & student==0
									
* Tecnicos completos 					
replace educ_anos_adult=11+3 if nivel_educ_adultne==6 & grado_educ_adultne==0 & student==0 & edad>16	
replace educ_anos_adult=11+grado_educ_adultne if nivel_educ_adultne==6 & grado_educ_adultne>0 & grado_educ_adultne<=3 &  student==0	
replace educ_anos_adult=11+(grado_educ_adultne*.5) if nivel_educ_adultne==6 & grado_educ_adultne>3 & grado_educ_adultne<=6 &  student==0	
replace educ_anos=14 if nivel_educ_adultne==6 & edu_hog_41=="No sabe/No responde" &  student==0	
replace educ_anos_adult=grado_educ_adultne if nivel_educ_adultne==6 & grado_educ_adultne>=7 & student==0
replace educ_anos_adult=15 if nivel_educ_adultne==6 & grado_educ_adultne==. & student==0

* Universitarios 
replace educ_anos_adult=11 if nivel_educ_adultne==7 & grado_educ_adultne==0 & student==0
replace educ_anos_adult=11+(grado_educ_adultne*0.5) if nivel_educ_adultne==7 &    		   	grado_educ_adultne>0 &  student==0		
replace educ_anos_adult=13 if nivel_educ_adultne==7 & grado_educ_adultne==. & student==0

* Uni completa
replace educ_anos_adult=16 if nivel_educ_adultne==8 & student==0

* Maestria 	
replace educ_anos_adult=16+(0.5*grado_educ_adultne) if nivel_educ_adultne==9 & student==0
replace educ_anos_adult=18 if nivel_educ_adultne==9 & grado_educ_adultne==. & student==0		

* Doctorado 					
replace educ_anos_adult=18 if nivel_educ_adultne==10 & student==0
replace educ_anos_adult=16+grado_educ_adultne*0.5 if nivel_educ_adultne==11 & student==0 
	

* Parents level of education 
gen temp3 = educ_anos_adult if mother == 1
bys idfamilia: egen educ_mom = mean(temp3)
gen temp4 = educ_anos_adult if father == 1
bys idfamilia: egen educ_dad = mean(temp4)
egen educ_padres_max = rowmax(educ_dad educ_mom)
drop temp*

save "$dta_clean/VenReps_MM_Variables.dta", replace 
