********************************************************************************
** 							Replication Files	   							  **
**						    Figures and Tables				  		 		  **	
** 			   			 Thriving Beyond Borders?							  **
**.             Understanding Refugee Children's Life Outcomes   		      **
**												 							  **
********************************************************************************

use "$dta_clean/VenReps_Kids_Final.dta", clear

*------------------------------------------------------------------------------*
* 								FIGURES										   *
*------------------------------------------------------------------------------*

********************************************************************************
* Figure 1: Characterizing Venezuelan Migration to Colombia 				   *
********************************************************************************
* a) Migrant's Distribution, 2018 Census 
* b) Inflows to Colombia 

********************************************************************************
* Figure 2: Location of Households in the VenReps Kids Sample 				   *
********************************************************************************

* 

******************************************************************************** 
* Figura 3: Wealth Index distribution										   *	
********************************************************************************
gen wi_total = wealth_index
gen wi_total_v = wealth_index_ven

local outcomes wi_total avg_material total_assets avg_servicios
foreach var of local outcomes {
	if "`var'"=="wi_total" {
		local xvar "Wealth Index"
	}
	if "`var'"=="avg_material" {
		local xvar "Average - Dwelling Material"
	}
	if "`var'"=="total_assets" {
		local xvar "Total Assets"
	}
	if "`var'"=="avg_servicios" {
		local xvar "Average - Access to Services"
	}
twoway kdensity `var' if venezuelan == 0 & first==1, lc(black) lw(medthick) /// 
lpattern(dash) ||   kdensity `var' if venezuelan == 1 & first==1, lc(red) 	///
lw(medthick) lpattern(shortdash_dot) || kdensity `var'_v if venezuelan == 1 ///
& first==1, lc(blue) lw(medthick) lpattern(dash_dot) legend( size(small)    ///
region(lwidth(none)) label(1 "Colombian") label (2 "Venezuelan") label 		///
(3 "Venezuelan: Before migrating")) graphregion(fcolor(white) color(white)) ///
ytitle(k-Density) xtitle(`xvar')
gr export  "$out/figures/avg_`var'_colven_pre_post.pdf", replace
}

******************************************************************************** 
* Figura 4: Years education distribution									   *	
********************************************************************************
cap label define ag 1"5-10 yrs" 2"11-17 yrs"
	cap label values group ag
	cap label define ven 0"Colombian" 1"Venezuelan"
	cap label values venezuelan ven 
	
	* Enrollment variables 
	local line lcolor(none)
	local lw lw(medthin)
	local per %100

	graph bar educ_anos_std, over(venezuelan, gap(*-5)) 						///
		over(group, gap(*2.5)) 													///
		asyvars ytitle(% Sisben registry) 										///
		bar(1, fcolor(eltgreen`per') `line'  `lw') 								///
		bar(2, fcolor(edkblue`per') `line'  `lw')								///
		graphregion(fcolor(none) lcolor(none)) bgcolor(white)  					///
		ytitle("Years of education (std)") 										///
		legend(order(1 "Colombian"  2 "Venezuelan") nobox region(lstyle(none))) ///
		blabel(bar, position(inside) format(%9.2f) color(white) size(medium)) 	
		gr export "$out/figures/years_educ_colven.pdf", replace
		
********************************************************************************
* Figure 5: Arrival Date Distribution							   			   *
********************************************************************************

preserve
* Add the parents information 
append using "$dta_clean/VenReps_MM_Variables.dta", force
twoway kdensity mig_date_ym if venezuelan == 1 & nino_enc==1 & mig_date_ym>= ///
tm(2015m5) & mig_date_ym<=tm(2021m12), lc(black) lw(medthick) ||  kdensity 	 ///
mig_date_ym if venezuelan == 1 & nino_enc!=1 & mig_date_ym>=tm(2015m5) & 	 ///
mig_date_ym<=tm(2021m12), lc(gs9) lw(medthick) lpattern(dash)  xlabel(664 	 ///
674 684 694 704 714 724 734 744, format(%tm) labsize(vsmall)) ylabel(, 		 ///
labsize(small)) legend(size(small) region(lwidth(none)) label(1 "Children")  ///
label (2 "Adults"))	graphregion(fcolor(white) color(white)) ytitle(Density)  ///
xtitle("Arrival date")
gr export "$out/figures/migration_dates_distribution.pdf", replace
restore

********************************************************************************
* Figure 6:  Service Access of Children and Adolescents	                       *
********************************************************************************

	cap label define ag 1"5-10 yrs" 2"11-17 yrs"
	cap label values group ag
	cap label define ven 0"Colombian" 1"Venezuelan"
	cap label values venezuelan ven 
	
	* Enrollment variables 
	local line lcolor(none)
	local lw lw(medthin)
	local per %100
	
	* School Enrollment
	graph bar enroll_ven_pre enroll_ven_t1 enroll_col,	 					 ///
		over(venezuelan, gap(*0.5)) over(group, gap(*0.2))					 ///
		legend(order(1 "pre-migration enrollment" 							 ///
					 2 "2022 enrollment") nobox 							 ///
		region(lstyle(none)) ) 	 graphregion(fcolor(white))				     ///
		bar(1, fcolor(edkblue`per') `line'  `lw') 							 ///
		bar(2, fcolor(gs11`per') `line'  `lw')								 ///
		bar(3, fcolor(eltgreen`per') `line'  `lw')							 ///
		blabel(bar, position(inside) format(%9.2f) color(white) size(medium)) ///
		graphregion(fcolor(none) lcolor(none)) bgcolor(white) 				 ///
		ytitle("Share of children enrolled")
		gr export "$out/figures/enrollment_colven_pre_post_new.pdf", replace
	
	* SISBEN Enrollment
	graph bar sisben_child, over(venezuelan, gap(*-5)) 						 ///
		over(group, gap(*2.5)) 												 ///
		asyvars ytitle(% Sisben registry) 									 ///
		bar(1, fcolor(eltgreen`per') `line'  `lw') 							 ///
		bar(2, fcolor(edkblue`per') `line'  `lw')							 ///
		graphregion(fcolor(none) lcolor(none)) bgcolor(white)  				///
		ytitle("Share of children enrolled") 								 ///
		legend(order(1 "Colombian"  2 "Venezuelan") nobox region(lstyle(none))) ///
		blabel(bar, position(inside) format(%9.2f) color(white) size(medium)) 
		gr export "$out/figures/sisben_col_ven_pre_post.pdf", replace
	 
	* Insurance Enrollment
	graph bar insurance_ven insurance_ven_t1 insurance_col ,	 			///
		over(venezuelan, gap(*0.5)) over(group, gap(*0.2))					///
		legend(order(1 "pre-migration insurance" 							///
					 2 "2022 insurance") nobox 							    ///
			region(lstyle(none)) ) 	 graphregion(fcolor(white))				///
		bar(1, fcolor(edkblue`per') `line'  `lw') 							///
		bar(2, fcolor(gs11`per') `line'  `lw')								///
		bar(3, fcolor(eltgreen`per') `line'  `lw')							///
		blabel(bar, position(inside) format(%9.2f) color(white) size(medium)) ///
		graphregion(fcolor(none) lcolor(none)) bgcolor(white) 				///
		ytitle("Share of children insured")
		gr export "$out/figures/insurance_col_ven_pre_post.pdf", replace	
		
	* Regularization Program 
	graph bar regular,over(group, gap(*1.5)) 									///
		asyvars ytitle(% Sisben registry) 										///
		bar(1, fcolor(eltgreen`per') lcolor(none)  `lw') 						///
		bar(2, fcolor(edkblue`per') `line'  `lw')								///
		bar(3, fcolor(eltgreen`per') `line'  `lw') 								///
		bar(4, fcolor(edkblue`per') `line'  `lw')								///	
		graphregion(fcolor(none) lcolor(none)) bgcolor(white)  					///
		ytitle("Share enrolled") 												///
		legend(order(1 "5-10 yrs"  2 "11-17 yrs") nobox region(lstyle(none)))   ///
		blabel(bar, position(inside) format(%9.2f) color(white) size(small)) 
		gr export "$out/figures/regularization_ven.pdf", replace
		
		
********************************************************************************
* Figure 7:Developmental Disparities Based on Duration of Residency in Colombia*
********************************************************************************
global max_controls sex_dumm age educ_padres_max wi_pooled 

eststo clear
local outcomes bmi_std pb_percentile
foreach x of local outcomes{
	
	if "`x'"=="bmi_std" {
		local ests bmi 
		local axisy "-0.5(0.1).1"
		local ytitle "BMI (std)"
	}
	if "`x'"=="pb_percentile" {
		local ests pbd 
		local axisy "-20(5)5"
		local ytitle "Test Percentile"
	}
	reg `x' tiempo1 tiempo2 tiempo3 $max_controls , robust				     ///
		cluster(idfamilia) 
	lincom tiempo1 - tiempo2       								
	local lab_reg1 = `:di %9.2f `r(p)''

	lincom tiempo1 - tiempo3       								
	local lab_reg2 = `:di %9.2f `r(p)''

	lincom tiempo2 - tiempo3 
	local lab_reg3 = `:di %9.2f `r(p)''

	eststo reg_`ests'_time

	local lw medthick
	local m1 circle
	
	coefplot																 ///
	(reg_`ests'_time, keep(tiempo1) mlabel(cond(`lab_reg1'<0.01, "***", 	 ///
	cond(`lab_reg1'<0.05, "**", cond(`lab_reg1'<0.1,"*", ""))) + 			 ///
	cond(`lab_reg2'<0.01, "***", cond(`lab_reg2'<0.05, "**", 				 ///
	cond(`lab_reg2'<0.1,"*", ""))) +  string(@b,"%9.2f"))   				 ///
	mlabformat("%9.2f")	mlabsize(medsmall) mcolor(green) levels(95 90) 		 ///
	ciopts(recast(. rcap) mlabposition(9) mlabgap(*2) 				         ///
	lcolor(green green ) lw(`lw' `lw')) m(`m1' ) )      				     ///
	(reg_`ests'_time, keep(tiempo2) mlabel(cond(`lab_reg1'<0.01, "***", 	 ///
	cond(`lab_reg1'<0.05, "**", cond(`lab_reg1'<0.1,"*", ""))) + 			 ///
	cond(`lab_reg3'<0.01, "***", cond(`lab_reg3'<0.05, "**", 				 ///
	cond(`lab_reg3'<0.1,"*", ""))) +  string(@b,"%9.2f"))    				 ///
	mlabformat("%9.2f")	mlabsize(medsmall) mcolor(green) levels(95 90) 		 ///
	ciopts(recast(. rcap) mlabposition(9) mlabgap(*2) 				         ///
	lcolor(green green ) lw(`lw' `lw')) m(`m1' ) )      				     ///
	(reg_`ests'_time, keep(tiempo3) mlabel(cond(`lab_reg2'<0.01, "***", 	 ///
	cond(`lab_reg2'<0.05, "**", cond(`lab_reg2'<0.1,"*", ""))) + 			 ///
	cond(`lab_reg3'<0.01, "***", cond(`lab_reg3'<0.05, "**", 				 ///
	cond(`lab_reg3'<0.1,"*", ""))) +  string(@b,"%9.2f"))        			 ///
	mlabformat("%9.2f")	mlabsize(medsmall) mcolor(green) levels(95 90) 		 ///
	ciopts(recast(. rcap) mlabposition(9) mlabgap(*2) 				         ///
	lcolor(green green ) lw(`lw' `lw')) m(`m1' )),							 ///
	plotregion(fcolor(white)) graphregion(style(none) fcolor(white) 		 ///
	color(white) lwidth(large)) bgcol(white) xlabel(, labsize(medsmall)) 	 ///
	nokey vertical	 														 /// 
	coeflabels( tiempo1 = "1-3 yrs" tiempo2 = "3-4 yrs" 					 ///
				tiempo3 = "4+ yrs", labgap(1))	   							 ///
	ylabel(`axisy', labsize(medsmall))  ytitle(`ytitle') 	  				 ///
	yline(0, lcolor(gray) lpattern(dash))									 


gr export "$out/figures/coefp_time_col_`ests'.pdf", replace
}

********************************************************************************
* Figure 8: Body Mass Index Gaps, Service Access, and Regularization Take-up   *
********************************************************************************
global max_controls sex_dumm age educ_padres_max wi_pooled 

eststo clear
local treatments ed sisb health regul 
foreach x of local treatments {
	if "`x'"=="ed" {
		local ests edu 
		local cq blue
		local lb1 "Enrolled"
		local lb2 "Not Enrolled"
	}
	if "`x'"=="sisb" {
		local ests sisben 
		local cq navy
		local lb1 "SS Access"
		local lb2 "No SS Access"
	}
	if "`x'"=="health" {
		local ests health 
		local cq blue
		local lb1 "Health Access"
		local lb2 "No Health Access"
	}
	if "`x'"=="regul" {
		local ests regular 
		local cq maroon
		local lb1 "Regular"
		local lb2 "Irregular"
	}
		
	reg bmi_std `x'2 `x'3 $max_controls , robust cluster(idfamilia) 
	lincom `x'2 - `x'3       								
	local lab_reg = `:di %9.2f `r(p)''
	eststo reg_bmi_`ests'

	local lw medthick
	local m1 circle
	local axisw "-0.5(0.1).1"
	local ytitle "BMI (std)"

	coefplot																 ///
	(reg_bmi_`ests', keep(`x'2) mlabel(cond(`lab_reg'<0.01, "***", 			 ///
	cond(`lab_reg'<0.05, "**", cond(`lab_reg'<0.1,"*", ""))) + 				 ///
	string(@b,"%9.2f"))   													 ///
	mlabformat("%9.2f")	mlabsize(medsmall) mcolor(`cq' `cq') levels(95 90)   ///
	ciopts(recast(. rcap) mlabposition(9) mlabgap(*2) 				         ///
	lcolor(`cq' `cq') lw(`lw')) m(`m1' ) )									 ///
	(reg_bmi_`ests', keep(`x'3) mlabel(cond(`lab_reg'<0.01, "***", 			 ///
	cond(`lab_reg'<0.05, "**", cond(`lab_reg'<0.1,"*", ""))) + 				 ///
	string(@b,"%9.2f"))   													 ///
	mlabformat("%9.2f")	mlabsize(medsmall) mcolor( `cq' `cq') levels(95 90)  ///
	ciopts(recast(. rcap) mlabposition(9) mlabgap(*2) 				         ///
	lcolor( `cq' `cq') lw(`lw' `lw')) m( `m1') ),							 ///
	plotregion(fcolor(white)) graphregion(style(none) fcolor(white)          ///
	color(white) lwidth(large)) bgcol(white)                                 ///
	xlabel(, labsize(medsmall)) nokey vertical								 ///
	coeflabels(`x'2="`lb1'" `x'3="`lb2'", labgap(1))    					 ///
	ylabel(`axisw', labsize(medsmall))  ytitle(`ytitle')    				 ///
	yline(0, lcolor(gray) lpattern(dash))					
	
gr export "$out/figures/coefp_`ests'_bmi_new.pdf", replace

}

********************************************************************************
*Figure 9:Cognitive Development Gaps,Service Access,and Regularization Take-up *
********************************************************************************
global max_controls sex_dumm age educ_padres_max wi_pooled 

eststo clear
local treatments ed sisb health regul 
foreach x of local treatments {
	if "`x'"=="ed" {
		local ests edu 
		local cq blue
		local lb1 "Enrolled"
		local lb2 "Not Enrolled"     
		local axisw "-30(5)5"
	}
	if "`x'"=="sisb" {
		local ests sisben 
		local cq navy
		local lb1 "SS Access"
		local lb2 "No SS Access"
		local axisw "-20(5)5"
	}
	if "`x'"=="health" {
		local ests health 
		local cq blue
		local lb1 "Health Access"
		local lb2 "No Health Access"
		local axisw "-15(5)5"
	}
	if "`x'"=="regul" {
		local ests regular 
		local cq maroon
		local lb1 "Regular"
		local lb2 "Irregular"
		local axisw "-25(5)5"
	}
		
	reg pb_percentile `x'2 `x'3 $max_controls , robust cluster(idfamilia) 
	lincom `x'2 - `x'3       								
	local lab_reg = `:di %9.2f `r(p)''
	eststo reg_pbd_`ests'

	local lw medthick
	local m1 circle
	
	local ytitle "Test Percentile"

	coefplot																 ///
	(reg_pbd_`ests', keep(`x'2) mlabel(cond(`lab_reg'<0.01, "***", 			 ///
	cond(`lab_reg'<0.05, "**", cond(`lab_reg'<0.1,"*", ""))) + 				 ///
	string(@b,"%9.2f"))   													 ///
	mlabformat("%9.2f")	mlabsize(medsmall) mcolor(`cq' `cq') levels(95 90)   ///
	ciopts(recast(. rcap) mlabposition(9) mlabgap(*2) 				         ///
	lcolor(`cq' `cq') lw(`lw')) m(`m1' ) )									 ///
	(reg_pbd_`ests', keep(`x'3) mlabel(cond(`lab_reg'<0.01, "***", 			 ///
	cond(`lab_reg'<0.05, "**", cond(`lab_reg'<0.1,"*", ""))) + 				 ///
	string(@b,"%9.2f"))   													 ///
	mlabformat("%9.2f")	mlabsize(medsmall) mcolor( `cq' `cq') levels(95 90)  ///
	ciopts(recast(. rcap) mlabposition(9) mlabgap(*2) 				         ///
	lcolor( `cq' `cq') lw(`lw' `lw')) m( `m1') ),							 ///
	plotregion(fcolor(white)) graphregion(style(none) fcolor(white)          ///
	color(white) lwidth(large)) bgcol(white)                                 ///
	xlabel(, labsize(medsmall)) nokey vertical								 ///
	coeflabels(`x'2="`lb1'" `x'3="`lb2'", labgap(1))    					 ///
	ylabel(`axisw', labsize(medsmall))  ytitle(`ytitle')    				 ///
	yline(0, lcolor(gray) lpattern(dash))					
	
gr export "$out/figures/coefp_`ests'_pbd_new.pdf", replace

}

******************************************************************************** 
* Figure B.1.: Peabody Vocabulary Test Score Distribution (5-17 years old)     *
********************************************************************************
foreach var of varlist peabody_std {
twoway kdensity `var'  if nino_enc==1 & filtro_0==1 , lc(ltblue) lw(medthick) || ///
kdensity `var'  if nino_enc==1 & filtro_0==2, lc(eltgreen) lw(medthick) 		 ///
lpattern(line) legend( label(1 "Colombian") label(2 "Venezuelan") size(small)) 	 ///
graphregion(fcolor(white) color(white) lwidth(large)) ytitle(k-Density, 		 ///
size(small)) ylabel(, labsize(small)) 											 ///
xtitle("Peabody Vocabulary Test" "(standarized)") 								 ///
xlabel(55 69"extremely low" 75 84"moderately low" 95 100"average" 115 135, 		 ///
labsize(small) angle(45)) xline(100, lc(red) lpattern(dash)) xline(69 84, 		 ///
lc(red) lpattern(dash)) legend(region(lwidth(none)) size(small))
gr export "$out/figures/`var'_colven_kdensity.pdf", replace
}

******************************************************************************** 
* Figure B.2.: Body Mass Index Distribution (5-10 year olds)				   *
********************************************************************************
foreach var of varlist bmi_std  {

twoway kdensity `var' if nino_enc==1 & group==1  & filtro_0==1, lc(ltblue)   ///
lw(medthick) || kdensity `var' if nino_enc==1 & group==1 & filtro_0==2 , 	 ///
lc(eltgreen) lw(medthick) lpattern(dash)  legend( label(1 "Colombian") 		 ///
label(2 "Venezuelan")) graphregion(fcolor(white) color(white) lwidth(large)) ///
ytitle(k-Density) xlabel(-1 "Underweight" 0 "Normal weight" 1 "Overweight",  ///	
labsize(small) angle(45)) xline(-1 0 1, lc(red) lpattern(dash)) 			 ///
xtitle("BMI" "(standarized by age in months)") legend(size(small) 			 ///
region(lwidth(none)))
gr export "$out/figures/`var'_col_ven_distribution.pdf", replace
}

******************************************************************************** 
* Figura B.3. and B.4.: Scales (GAD 7, SDQ, TSCYC PHQ) distribution			   *	
********************************************************************************

local outcomes gad7_score sdq_score tscore_tscyc phq_score
foreach var of local outcomes {
		if "`var'"=="gad7_score" {
		local xset 4 "minimal anxiety" 5 9 "mild anxiety" 10                 ///
		14 "moderate anxiety" 15 20 21 "severe anxiety"
		local xnum 4 9 14 21
			}
		if "`var'"=="sdq_score" {
		local xset 5 10 13 "Normal" 15 16 "Borderline" 17 "Abnormal" 20 25 30
		local xnum 13 16 17
			}
		if "`var'"=="tscore_tscyc" {
		local xset 40 45 50 55 60 65 "At-risk" 70 75 80 85
		local xnum 65
			}
		if "`var'"=="phq_score" {
		local xset 3 5 "mild depression" 7 10 "moderate depression" 12       ///
		15 "moderate severe depression" 17 20 "severe depression" 22 27
		local xnum 5 10 15 20
		}
twoway kdensity `var' if nino_enc==1 & filtro_0==1, lc(ltblue) lw(medthick) ||  ///
kdensity `var' if nino_enc==1 & filtro_0==2 , lc(eltgreen) lw(medthick) 		///
lpattern(dash)  legend( label(1 "Colombian") label(2 "Venezuelan")) 			///
graphregion(fcolor(white) color(white) lwidth(large)) ytitle(k-Density) 		///
xlabel(`xset',labsize(small) angle(45))  xline(`xnum', lc(red) lpattern(dash)) 	///
xtitle("Score") legend(size(small) region(lwidth(none)))
gr export "$out/figures/`var'_colven_kdensity.pdf", replace
}

*------------------------------------------------------------------------------*
* 								TABLES										   *
*------------------------------------------------------------------------------*
******************************************************************************** 
* Table 1: Legal Rights and Services for Venezuelan Children and Adolescents   *
* in Colombia												        		   *	
********************************************************************************


******************************************************************************** 
* Table 2: Descriptive Statistics for Adults								   *	
********************************************************************************
preserve
use "$dta_clean/VenReps_MM_Variables", clear  

	eststo clear 
	* Change labels to the ones to be exported in table
	label var sex_dumm  "Male [=1]"
	label var edad "Age (Years)"
	label var educ_anos_adult "Years of Education"
	label var married_adult "Married [=1]"
	
	label var sisben "Sisbén Enrollment [=1]"
	label var student_adult "Student [=1]"
	label var health_adult "Health Insurance [=1]"
		
	label var unemployed "Unemployed [=1]"
	label var self_employed "Self-employed [=1]"
	label var informal "Informal [=1]"
	label var contract_adult "Work contract [=1]"
	
	keep if parent == 1 | eresp ==1 | careg == 1 
	
	local i = 1 
	foreach var of varlist sex_dumm edad educ_anos_adult married_adult 	///
		sisben student_adult health_adult 									///
		unemployed self_employed informal contract_adult {
		
		* Colombians 
		eststo c`i': estpost summarize `var' if venezuelan == 0  
		
		* Venezuelans 
		eststo v`i': estpost summarize `var'  if venezuelan == 1  
		
			* TTEST Col-Ven
		eststo d`i': estpost ttest `var', by(venezuelan)	  
		
		dis " variable # `i' = `var'"
		local i = `i' + 1
}

	local meanop mean( pattern(1 1 0 0) fmt(2))
	local bop b(pattern(0 0 1) fmt(2) star)
	local seop se(pattern(0 0 1)  fmt(2) par( ( ) ))
	local sdop sd(pattern(1 1 0 0) fmt(2) par( [ ] ))
	local options cells( "`meanop' `bop' " " `sdop' `seop' ")				///
		 nonumbers nogaps nolines noobs 									///
		fragment tex nomtitles nobaselevels collabels(none)
		
	* Individual characteristics 1-9	
	esttab c1 v1 d1 														///
	using "$out/tables/desc_adults_indiv", replace `options' label	
		
	forvalues x = 2(1)4 {
		esttab c`x' v`x' d`x' 												///
			using "$out/tables/desc_adults_indiv", append  	///
			`options' label	
	}
	
	* Access to services 5-7	
	esttab c5 v5 d5 														///
	using "$out/tables/desc_adults_serv", replace `options' label	
		
	forvalues x = 6(1)7 {
		esttab c`x' v`x' d`x' 												///
			using "$out/tables/desc_adults_serv", append  	///
			`options' label	
	}	
	* Access to services 8-11	
	esttab c8 v8 d8 														///
	using "$out/tables/desc_adults_emp", replace `options' label	
		
	forvalues x = 9(1)11 {
		esttab c`x' v`x' d`x' 												///
			using "$out/tables/desc_adults_emp", append  	///
			`options' label	
	}	
	
	* Observations (All panels)
	eststo c12: estpost ttest venezuelan, by(venezuelan)

	
	esttab c12			///
		using "$out/tables/obs_adults", replace       ///
		cell("N_1(fmt(%12.0fc)) N_2(fmt(%12.0fc)) count(fmt(%12.0fc))") nonumbers nogaps nolines noobs 		///
		fragment tex nomtitles nobaselevels collabels(none) coeflabel(venezuelan "Observations (All panels)")

restore

******************************************************************************** 
* Table 3: Households Descriptive Statistics								   *	
********************************************************************************
preserve
use "$dta_clean/VenReps_HH_Variables", clear  
* Change labels to the ones to be exported in table
	label var hh_size "Household size"
	label var tot_adult  "\# Adults (3,617)"
	label var menores_hogar "\# Children (3,169)"
	label var total_assets "Assets (Max=15)"
	label var own_hh "Own dwelling [=1]"

	bys idfamilia: keep if _n == 1
	
	local i = 1 
	foreach var of varlist  												///
		hh_size tot_adult  menores_hogar total_assets own_hh {
		
		* Colombians 
		eststo c`i': estpost summarize `var' if venezuelan == 0  
		
		* Venezuelans 
		eststo v`i': estpost summarize `var'  if venezuelan == 1  
		
			* TTEST Col-Ven
		eststo d`i': estpost ttest `var', by(venezuelan)	  
		
		dis " variable # `i' = `var'"
		local i = `i' + 1
}

	local meanop mean( pattern(1 1 0 0) fmt(2))
	local bop b(pattern(0 0 1) fmt(2) star)
	*local nop count (pattern(1 1 0 0) fmt(0))
	local seop se(pattern(0 0 1)  fmt(2) par( ( ) ))
	local sdop sd(pattern(1 1 0 0) fmt(2) par( [ ] ))
	local options label cells( "`meanop' `bop' " " `sdop' `seop' ")			///
		 nonumbers nogaps nolines noobs 									///
		fragment tex nomtitles nobaselevels collabels(none)

	* Household Characteristics
	forvalues x = 1(1)5 {
		esttab c`x' v`x' d`x' 												///
		using "$out/tables/desc_household.tex", 			///
			append  `options'	
	}

	* Observations (All panels)
	eststo c6: estpost ttest venezuelan, by(venezuelan)

	
	esttab c6			///
		using "$out/tables/obs_hh", replace       ///
		cell("N_1(fmt(%12.0fc)) N_2(fmt(%12.0fc)) count(fmt(%12.0fc))") nonumbers nogaps nolines noobs 		///
		fragment tex nomtitles nobaselevels collabels(none) coeflabel(venezuelan "Observations")
restore

******************************************************************************** 
* Table 4: Children Descriptives												   *	
********************************************************************************
eststo clear 
	* Change labels to the ones to be exported in table
	label var sex_dumm  "Male [=1]"
	label var edad "Age (Years)"
	label var educ_anos_std "Years Education (standarized)"
	
local i = 1 
foreach var of varlist edad sex_dumm educ_anos_std {
		
	* Colombians 
	eststo c`i': estpost summarize `var' if venezuelan == 0  
		
	* Venezuelans 
	eststo v`i': estpost summarize `var'  if venezuelan == 1  
		
			* TTEST Col-Ven
	eststo d`i': estpost ttest `var', by(venezuelan)	  
		
		dis " variable # `i' = `var'"
		local i = `i' + 1
}


local meanop mean( pattern(1 1 0 0) fmt(2))
local bop b(pattern(0 0 1) fmt(2) star)
	*local nop count (pattern(1 1 0 0) fmt(0))
local seop se(pattern(0 0 1)  fmt(2) par( ( ) ))
local sdop sd(pattern(1 1 0 0) fmt(2) par( [ ] ))
local options label cells( "`meanop' `bop' " " `sdop' `seop' ")				///
		 nonumbers nogaps nolines noobs 									///
		fragment tex nomtitles nobaselevels collabels(none)

* Export : Descriptives table (characteristics children)
	* Creates file
esttab c1 v1 d1 															///
		using "$out/tables/desc_children.tex", 				///
			replace `options' 	
forvalues x = 2(1)3 {
	esttab c`x' v`x' d`x' 													///
		using "$out/tables/desc_children.tex", append  `options'	
}

* Observations (All panels)
	eststo c4: estpost ttest venezuelan, by(venezuelan)

	
	esttab c4			///
		using "$out/tables/obs_kids", replace       ///
		cell("N_1(fmt(%12.0fc)) N_2(fmt(%12.0fc)) count(fmt(%12.0fc))") nonumbers nogaps nolines noobs 		///
		fragment tex nomtitles nobaselevels collabels(none) coeflabel(venezuelan "Total children")
		
	
******************************************************************************** 
* Table 5: Assessing Physical Development Gaps (children 5-10 years old).      *	
********************************************************************************
		
reg bmi_std venezuelan  $max_controls if nino_enc == 1 & group==1
gen samp_bmi = e(sample)

eststo clear
local outcomes bmi_std low_weight overweight sick_child
foreach x of local outcomes {
foreach t in 1 2 3{
		
		if `t' == 1 {
			local controls 
		}
		
		if `t' == 2 {
			local controls sex_dumm age educ_padres_max wi_pooled 
		}	
		
		if `t' == 3 {
			local controls sex_dumm age educ_padres_max wi_pooled     ///
					
		}	
					
		
		if "`x'"=="bmi_std" {
		local ests bmi
			}
			
		if "`x'"=="low_weight" {
		local ests loww
			}
			
		if "`x'"=="overweight" {
		local ests overw
			}
		if "`x'"=="sick_child" {
		local ests sick
		}
		 if `t' != 3 {
		eststo reg1_`t'_`ests' : 						///
		reg `x' venezuelan `controls' if group==1 & samp_bmi == 1 , 						///
		robust cluster(idfamilia)	
		local n`ests'= e(N)
		sum `x' if venezuelan==0 & group==1
		estadd scalar m_`ests'= `r(mean)'
		 }
		 if `t' == 3 {
		 eststo reg1_`t'_`ests' : 						///
		 bootstrap "psmatch2 venezuelan `controls' if group==1 & samp_bmi == 1, outcome(`x') ate " r(ate) , ///
		 cluster(idfamilia) 
		 local n`ests'= e(N)
		 sum `x' if venezuelan==0 & group==1
		 estadd scalar m_`ests'= `r(mean)'
		 }
	     }
	   }
	   
esttab reg1_1_bmi reg1_2_bmi reg1_3_bmi reg1_1_loww reg1_2_loww reg1_3_loww     ///
using "$out/tables/reg_bmi_loww_new", rename(_bs_1 venezuelan)  		///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant")      									///
stats(r2 N m_bmi m_loww, 														///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)" 		///
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines
 	
esttab reg1_1_overw reg1_2_overw reg1_3_overw reg1_1_sick reg1_2_sick reg1_3_sick  ///
using "$out/tables/reg_overw_sick_new", rename(_bs_1 venezuelan)  		///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment  											///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant")											///
stats(r2 N m_overw m_sick, 														///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)" 		///
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs


******************************************************************************** 
* Table 6: Assessing Cognitive Development Gaps (5-17 years old) 													   *	
********************************************************************************
global max_controls sex_dumm age educ_padres_max wi_pooled 
		
reg pb_percentile venezuelan  $max_controls if nino_enc == 1
gen samp_pb = e(sample)

eststo clear 
local outcomes pb_percentile pb_ext_low pb_mod_low pb_low
foreach x of local outcomes {

	foreach t in 1 2 3{
		
		if `t' == 1 {
			local controls 
		}
		
		if `t' == 2 {
			local controls sex_dumm age educ_padres_max wi_pooled 
		}	
		
		if `t' == 3 {
			local controls sex_dumm age educ_padres_max wi_pooled     ///
					
		}	
		
		if "`x'"=="pb_percentile" {
		local ests pb_percentile
			}
		if "`x'"=="pb_ext_low" {
		local ests pb_ext_low
			}
		if "`x'"=="pb_mod_low" {
		local ests pb_mod_low
			}
		if "`x'"=="pb_low" {
		local ests pb_low
			}
			
		 if `t' != 3 {
		eststo reg1_`t'_`ests' : 						///
		reg `x' venezuelan `controls' if samp_pb == 1 , 						///
		robust cluster(idfamilia)	
		sum `x' if venezuelan==0 & group==1
		estadd scalar m_`ests'= `r(mean)'
		 }
		 if `t' == 3 {
		 eststo reg1_`t'_`ests' : 						///
		 bootstrap "psmatch2 venezuelan `controls' if samp_pb == 1, outcome(`x') ate " r(ate) , ///
		 cluster(idfamilia) 
		 sum `x' if venezuelan==0 & group==1
		estadd scalar m_`ests'= `r(mean)'
		 }
		}
}

esttab reg1_1_pb_percentile reg1_2_pb_percentile reg1_3_pb_percentile 			///
reg1_1_pb_ext_low reg1_2_pb_ext_low reg1_3_pb_ext_low 							///
using "$out/tables/reg_pb_percentile_ext_low", rename(_bs_1 venezuelan) ///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant") 										///
stats(r2 N m_pb_percentile m_pb_ext_low , 										///	
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)" 		///
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs

esttab reg1_1_pb_mod_low reg1_2_pb_mod_low reg1_3_pb_mod_low 					///
reg1_1_pb_low reg1_2_pb_low reg1_3_pb_low 										///
using "$out/tables/reg_pb_mod_low", rename(_bs_1 venezuelan)  			///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant") 										///
stats(r2 N m_pb_mod_low m_pb_low, 												///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)" 		///
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs


******************************************************************************** 
* Table 7:Assessing Socioemotional and Mental Development Gaps (5-17 years old)*	
********************************************************************************


eststo clear 
local outcomes tscore_tscyc risk65_tscyc sdq_score sdq_score_3 gad7_score phq_score
foreach x of local outcomes {

	foreach t in 1 2 3{
		
		if `t' == 1 {
			local controls 
		}
		
		if `t' == 2 {
			local controls sex_dumm age educ_padres_max wi_pooled 
		}	
		
		if `t' == 3 {
			local controls sex_dumm age educ_padres_max wi_pooled     ///
					
		}	
		
		if "`x'"=="tscore_tscyc" {
		local ests tscyc_std
			}
		if "`x'"=="risk65_tscyc" {
		local ests atrisk_tscyc
			}
		if "`x'"=="sdq_score" {
		local ests sdq
			}
		if "`x'"=="sdq_score_3" {
		local ests abnormal_sdq
			}
		if "`x'"=="gad7_score" {
		local ests gad7
			}
		if "`x'"=="phq_score" {
		local ests phq
			}
			
		 if `t' != 3 {
		eststo reg1_`t'_`ests' : 						///
		reg `x' venezuelan `controls' , 						///
		robust cluster(idfamilia)	
		sum `x' if venezuelan==0
		estadd scalar m_`ests'= `r(mean)'
		 }
		 if `t' == 3 {
		 eststo reg1_`t'_`ests' : 						///
		 bootstrap "psmatch2 venezuelan `controls', outcome(`x') ate " r(ate) , ///
		 cluster(idfamilia) 
		 sum `x' if venezuelan==0
		estadd scalar m_`ests'= `r(mean)'
		 }
		} 
}

esttab reg1_1_tscyc_std reg1_2_tscyc_std reg1_3_tscyc_std 						///
reg1_1_atrisk_tscyc reg1_2_atrisk_tscyc reg1_3_atrisk_tscyc  					///
using "$out/tables/reg_tscyc", rename(_bs_1 venezuelan)  				///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant")   										///
stats(r2 N m_tscyc_std m_atrisk_tscyc, 											///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)"		///
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs

esttab reg1_1_sdq reg1_2_sdq reg1_3_sdq 										///
reg1_1_abnormal_sdq reg1_2_abnormal_sdq reg1_3_abnormal_sdq 					///
using "$out/tables/reg_sdq", rename(_bs_1 venezuelan)  					///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant") 										///
stats(r2 N m_sdq m_abnormal_sdq, 												///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)"		///
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs

esttab reg1_1_gad7 reg1_2_gad7 reg1_3_gad7 reg1_1_phq reg1_2_phq reg1_3_phq     ///
using "$out/tables/reg_gad7_phq", rename(_bs_1 venezuelan)  			///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant") 										///
stats(r2 N m_gad7 m_phq, 														///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)"		/// 
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs

******************************************************************************** 
* Table 8:Assessing Social Cohesion (11-17 years old)						   *	
********************************************************************************

eststo clear 
local outcomes log_alt conf_1_std conf_2_std conf_3_std conf_4_std identity_21_std discri friends 
foreach x of local outcomes {

	foreach t in 1 2 3{
		
		if `t' == 1 {
			local controls 
		}
		
		if `t' == 2 {
			local controls sex_dumm age educ_padres_max wi_pooled 
		}	
		
		if `t' == 3 {
			local controls sex_dumm age educ_padres_max wi_pooled     ///
					
		}	
		
		if "`x'"=="log_alt" {
		local ests altru
			}
		if "`x'"=="conf_1_std" {
		local ests trust1
			}
		if "`x'"=="conf_2_std" {
		local ests trust2
			}
		if "`x'"=="conf_3_std" {
		local ests trust3
			}
		if "`x'"=="conf_4_std" {
		local ests trust4
			}
		if "`x'"=="identity_21_std" {
		local ests identity2
			}
		if "`x'"=="discri" {
		local ests discri
			}
		if "`x'"=="friends" {
		local ests friends
			}
					
		 if `t' != 3 {
		eststo reg1_`t'_`ests' : 						///
		reg `x' venezuelan `controls', 						///
		robust cluster(idfamilia)	
		sum `x' if venezuelan==0
		estadd scalar m_`ests'= `r(mean)'
		 }
		 if `t' == 3 {
		 eststo reg1_`t'_`ests' : 						///
		 bootstrap "psmatch2 venezuelan `controls', outcome(`x') ate " r(ate) , ///
		 cluster(idfamilia) 
		 sum `x' if venezuelan==0
		estadd scalar m_`ests'= `r(mean)'
		 }
		}
	}

esttab reg1_1_altru reg1_2_altru reg1_3_altru 									///
reg1_1_trust1 reg1_2_trust1 reg1_3_trust1  										///
using "$out/tables/reg_altru_trust1", rename(_bs_1 venezuelan)  		///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant")   										///
stats(r2 N m_altru m_trust1, 													///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)"		///
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs

esttab reg1_1_trust2 reg1_2_trust2 reg1_3_trust2 								///
reg1_1_trust3 reg1_2_trust3 reg1_3_trust3  										///
using "$out/tables/reg_trust2_trust3", rename(_bs_1 venezuelan)  		///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant") 										///
stats(r2 N m_trust2 m_trust2, 													///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)" 			///
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs
			 
esttab reg1_1_trust4 reg1_2_trust4 reg1_3_trust4 								///
reg1_1_identity2 reg1_2_identity2 reg1_3_identity2  							///
using "$out/tables/reg_trust4_identity2", rename(_bs_1 venezuelan)  	///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant")   										///
stats(r2 N m_trust4 m_identity2, 											///
labels("R-squared" "Observations"  "Mean Dep. Variable (Colombian sample)" 			///
"Mean Outcome"))																///
mlabels(none) nonumbers nogaps	nolines noobs
			 
esttab reg1_1_discri reg1_2_discri reg1_3_discri 								///
reg1_1_friends reg1_2_friends reg1_3_friends  									///
using "$out/tables/reg_discri_friends", rename(_bs_1 venezuelan) 		///
label tex																		///
b(%9.2f) se(%9.2f) replace fragment nobaselevels 								///
star(* .1 ** .05 *** .01)														///
keep(venezuelan)																///
coeflabels(venezuelan "Forced Migrant")   										///
stats(r2 N m_discri m_friends, 													///
labels("R-squared" "Observations" "Mean Dep. Variable (Colombian sample)"				/// 
"Mean Dep. Variable (Colombian sample)"))										///
mlabels(none) nonumbers nogaps	nolines noobs

********************************************************************************
*Table A3:Sample Comparison between PEP National Migrant Survey and VenReps Kids* 
********************************************************************************
preserve
********************************************************************************
************************ 	  Muestra censo RAMV 	 	************************
********************************************************************************

* Load data
use "$dta//PEP/ramv_pep.dta", clear
sort id_fam

drop if other_nat==1
	
	gen male=(gender==2)

 *) Yrs of education
	gen educ_yrs=.
	* Preescolar
	replace educ_yrs=0 if education==2 
	* Primaria 
	replace educ_yrs=5 if education==3 
	* Secundaria 
	replace educ_yrs=11 if education==4
	* Tecnológicos 
	replace educ_yrs=15 if education==5
	* Universitario 
	replace educ_yrs=16 if education==6
	* Post Grado 
	replace educ_yrs=18 if education==7

	* Rename variables to match venreps
	rename educ_yrs educ_anos_adult
	rename marital_status1 married
	rename o_2 informal
	rename o_3 self_employed
	rename o_4 unemployed
	rename fam_size hh_size 
	* Keep only household head
	keep if relation == 1
	bysort id_fam relation : gen count = _n if relation==1
	tab count
	drop if count > 1 // drop hh with more than one head

	keep  male age educ_anos_adult married self_employed unemployed informal hh_size

	* Create Base Code
	gen base = 3
	
	tempfile pep
	save `pep'
	
********************************************************************************
************************ 	  Muestra VEN REPS ADULTS  	************************
********************************************************************************

* Load data
use "$dta/PEP/final_base.dta", clear
*keep if demo_1061==2

keep if orden==1 // keep only household head

gen adultos_hogar = size - child_venez
gen male = (female==0)
gen married = (demo_104==2 | demo_104==3)
gen informal = (ocupado ==1 & formal == 0)

ren size hh_size
ren child_venez menores_hogar 
ren yrseduc educ_anos_adult

* self employed
gen self_employed = .
replace self_employed = 0 if employed == 1
replace self_employed = 1 if ocu_217 >= 4 & ocu_217 <= 7 

keep adultos_hogar male age educ_anos_adult married self_employed unemployed informal hh_size menores_hogar

gen base=2
	tempfile venreps
	save `venreps'

********************************************************************************
************************ 	  Muestra VEN REPS KIDS	 	************************
********************************************************************************
* HOUSEHOLD
use "$dta_clean/VenReps_HH_Variables",clear

	* keep only venezuelans
	drop if filtro_0 == 1
	* Create Base Code 
	gen base = 3	
	* Change from string to long (variable's original names unchanged)	
	destring idfamilia, replace
	
	*ren menores_hogar menores_hogar2
	*rename filtro_11 menores_hogar
	keep idfamilia base hh_size menores_hogar
	
tempfile hh
save `hh'

* ADULTS
use "$dta_clean/VenReps_MM_Variables.dta", clear
destring idfamilia, replace
	* keep only venezuelans
	drop if filtro_0 == 1
	* keep only household head 
	gen jefe_hogar = (parentesco == "01. Es el jefe o la jefe de hogar" | parentesco == "01.  Es el jefe o la jefe de hogar")
	keep if jefe_hogar == 1
	ren id idpersona
	destring idpersona, replace
	* drop families with more than one household head
	bysort idfamilia jefe_hogar : gen count = _n if jefe_hogar == 1
	tab count 
	drop if count > 1
	* educ_anos_adult : Years of education for Adults 
	  label var educ_anos_adult "Years of education for Adults"
	* sexo : sexo al nacer 
	  gen male = (sexo == 1)
	 * Married
	 gen married=(hog_7==3 | hog_7==2)

	* Create Base Code 
	drop base
	gen base = 1			  
	
	* merge with household variables 
	merge 1:1 idfamilia using `hh'
	* pegaron 860 (que son las que reportaron jefe de hogar, los restantes no reportaron jefe de hogar)
	keep if _merge == 3
	drop _merge
	
	
	keep idfamilia base filtro_0 adultos_hogar male age educ_anos_adult married 	///
	self_employed unemployed informal hh_size menores_hogar
 
tempfile mm
save `mm'
********************
* APPEND WITH DATA *
********************

use `mm', clear
append using `pep'
append using `venreps'

* check duplicates
	duplicates report idfamilia if base == 1
	duplicates report idfamilia if base == 2
	* bien no hay duplicados 

* Labels
label var male "Male [=1]"
label var married "Married [=1]"
label var self_employed "Self-employed [=1]"
label var unemployed "Unemployed [=1]"
label var informal "Informal [=1]"
label var adultos_hogar "Adults"
label var menores_hogar "Children"
label var educ_anos_adult "Years of education"
label var hh_size "Household size"


********************************************************************************
************************ 	 		OUTPUT			 	************************
********************************************************************************

local vars  hh_size adultos_hogar menores_hogar male age educ_anos_adult married self_employed unemployed informal
local vars2 hh_size male age educ_anos_adult married self_employed unemployed informal
eststo t1: 	quietly estpost summ  `vars2' if base == 3
eststo t2:  quietly estpost summ  `vars' if base == 2
eststo t3:  quietly estpost summ  `vars' if base == 1
eststo t4: 	quietly estpost summ  `vars'
eststo t5:	quietly estpost ttest `vars' if base==1 | base==2, by(base) unequal // venreps
eststo t6:	quietly estpost ttest `vars2' if base==1 | base==3, by(base) unequal // pep


esttab t3 t2 t1 t5 t6  using "$out/tables/pep_venrepskids.tex", replace label compress nonote nogaps ///
cells("mean(pattern(1 1 1 0 0) fmt(2)) b(star pattern(0 0 0 1 1) fmt(2))" "sd(pattern(1 1 1 0 0) par fmt(2)) se(pattern(0 0 0 1 1) par fmt(2))") ///
collabels(,none) mtitle("VenReps Kids" "VenReps" "RAMV" "(1) - (2)" "(1) - (3)") ///
refcat(hh_size "\textbf{Household}" male "\vspace{0.1em} \\ \textbf{Household Head}", nolabel) 


restore

********************************************************************************
*    Table B1:  Access to services - School Enrollment						   * 
********************************************************************************

replace years_incol_decimals=0 if venezuelan==0
rename years_incol_decimals yearscol_dec





	* Change labels to the ones to be exported in table
	label var sex_dumm  "Male (\%)"
	label var edad "Age"
	label var educ_anos "Years of Education"
	label var parent_careg "Parents Main Careigver [=1]"
	label var yearscol_dec "Years in Colombia"
	
eststo clear 	
global services enroll
foreach x in $services {	

foreach var of varlist edad sex_dumm educ_anos parent_careg yearscol_dec{
		
	* Colombians 
	eststo ce_`var'_`x': estpost sum `var' if venezuelan == 0 & `x'==1
	eststo cne_`var'_`x': estpost sum `var' if venezuelan == 0 & `x'==0
		
	* Venezuelans 
	eststo ve_`var'_`x': estpost sum `var'  if venezuelan == 1 & `x'==1
	eststo vne_`var'_`x': estpost sum `var'  if venezuelan == 1 & `x'==0
	
	* TTEST Col-Ven
	eststo diffcol_`var'_`x': estpost ttest `var' if venezuelan == 0, by(`x')
	eststo diffven_`var'_`x': estpost ttest `var' if venezuelan == 1, by(`x')

local meanop mean( pattern(1 1 0 1 1 0) fmt(2))
	local bop b( pattern(0 0 1 0 0  1) fmt(2) star)
	local seop se(pattern(0 0 1 0 0 1)  fmt(2) par( ( ) ))
	local sdop sd(pattern(1 1 0 1 1 0) fmt(2) par( [ ] ))
	local options label cells(  "`meanop' `bop' " " `sdop' `seop' ")				///
		 nonumbers nogaps nolines noobs 									///
		fragment tex nomtitles nobaselevels collabels(none)
		
esttab ce_`var'_`x' cne_`var'_`x' diffcol_`var'_`x' ve_`var'_`x' vne_`var'_`x' diffven_`var'_`x'													///
	using "$out/tables/desc_`x'.tex", append  `options'	
}
   
}

* Observations (All panels)
	eststo enroll1: estpost ttest enroll if venezuelan == 0, by(enroll)
	eststo enroll2: estpost ttest enroll if venezuelan == 1, by(enroll)
	
	esttab enroll1 enroll2	 		///
		using "$out/tables/obs_enroll_kids", replace      							 ///
		cell("N_2(fmt(%12.0fc)) N_1(fmt(%12.0fc)) mu_1(fmt(0))") nonumbers nogaps nolines noobs 		///
		fragment tex nomtitles nobaselevels collabels(none) coeflabel(enroll "Observations")
		
		
foreach i in wi_pooled {

	sum `i' if venezuelan==0
	local mean = `r(mean)'
	local sd = `r(sd)'
	gen `i'_std=(`i'- `mean')/`sd'			
}


rename wi_pooled_std wip_std
rename menores_hogar menores 

preserve
bys idfamilia: gen total_familia = _n
keep if total_familia==1 
* Change labels to the ones to be exported in table
	label var hh_size "Household size"
	label var menores "\# Child"
	label var total_assets "Total Assets"
	label var wip_std "Wealth Index (std)"
	
eststo clear 
global services enroll
foreach x in $services {	

foreach var of varlist hh_size menores total_assets wip_std{
		
	* Colombians 
	eststo ce_`var'_`x': estpost sum `var' if venezuelan == 0 & `x'==1
	eststo cne_`var'_`x': estpost sum `var' if venezuelan == 0 & `x'==0
		
	* Venezuelans 
	eststo ve_`var'_`x': estpost sum `var'  if venezuelan == 1 & `x'==1
	eststo vne_`var'_`x': estpost sum `var'  if venezuelan == 1 & `x'==0
	
	* TTEST Col-Ven
	eststo diffcol_`var'_`x': estpost ttest `var' if venezuelan == 0, by(`x')
	eststo diffven_`var'_`x': estpost ttest `var' if venezuelan == 1, by(`x')

	local meanop mean( pattern(1 1 0 1 1 0) fmt(2))
	local bop b(pattern(0 0 1 0 0 1) fmt(2) star)
	local seop se(pattern(0 0 1 0 0 1)  fmt(2) par( ( ) ))
	local sdop sd(pattern(1 1 0 1 1 0) fmt(2) par( [ ] ))
	local options label cells( "`meanop' `bop' " " `sdop' `seop' ")			///
		 nonumbers nogaps nolines noobs 									///
		fragment tex nomtitles nobaselevels collabels(none)
		
esttab ce_`var'_`x' cne_`var'_`x' diffcol_`var'_`x' ve_`var'_`x' vne_`var'_`x' diffven_`var'_`x'				///
		using "$out/tables/desc_hh_`x'.tex", append  `options'	
}
   
}

* Observations (All panels)
	eststo enroll1: estpost ttest enroll if venezuelan == 0, by(enroll)
	eststo enroll2: estpost ttest enroll if venezuelan == 1, by(enroll)
	
	esttab enroll1 enroll2	 		///
		using "$out/tables/obs_enroll_hh", replace      							 ///
		cell("N_2(fmt(%12.0fc)) N_1(fmt(%12.0fc)) mu_1(fmt(0))") nonumbers nogaps nolines noobs 		///
		fragment tex nomtitles nobaselevels collabels(none) coeflabel(enroll "Observations")
restore

use "$dta_clean/VenReps_MM_Variables", clear 

keep if eresp==1

rename educ_anos_adult educadult
rename married_adult marriedad
rename total_enroll enroll_mm

* Change labels to the ones to be exported in table
	label var employed "Employed [=1]"
	label var educadult "Years of education"
	label var marriedad "Married [=1]"
	
	
global services enroll_mm
foreach x in $services {	

foreach var of varlist employed educadult marriedad {
		
	* Colombians 
	eststo ce_`var'_`x': estpost sum `var' if venezuelan == 0 & `x'==1
	eststo cne_`var'_`x': estpost sum `var' if venezuelan == 0 & `x'==0
		
	* Venezuelans 
	eststo ve_`var'_`x': estpost sum `var'  if venezuelan == 1 & `x'==1
	eststo vne_`var'_`x': estpost sum `var'  if venezuelan == 1 & `x'==0
	
	* TTEST Col-Ven
	eststo diffcol_`var'_`x': estpost ttest `var' if venezuelan == 0, by(`x')
	eststo diffven_`var'_`x': estpost ttest `var' if venezuelan == 1, by(`x')

local meanop mean( pattern(1 1 0 1 1 0) fmt(2))
	local bop b(pattern(0 0 1 0 0 1) fmt(2) star)
		local seop se(pattern(0 0 1 0 0 1)  fmt(2) par( ( ) ))
	local sdop sd(pattern(1 1 0 1 1 0) fmt(2) par( [ ] ))
	local options label cells( "`meanop' `bop' " " `sdop' `seop' ")			///
		 nonumbers nogaps nolines noobs 									///
		fragment tex nomtitles nobaselevels collabels(none)
		
esttab ce_`var'_`x' cne_`var'_`x' diffcol_`var'_`x' ve_`var'_`x' vne_`var'_`x' diffven_`var'_`x'				///												///
		using "$out/tables/desc_adult_`x'.tex", append  `options'	
}
   
}
* Observations (All panels)
	eststo enroll1: estpost ttest enroll_mm if venezuelan == 0, by(enroll_mm)
	eststo enroll2: estpost ttest enroll_mm if venezuelan == 1, by(enroll_mm)
	
	esttab enroll1 enroll2	 		///
		using "$out/tables/obs_enroll_adults", replace      							 ///
		cell("N_2(fmt(%12.0fc)) N_1(fmt(%12.0fc)) mu_1(fmt(0))") nonumbers nogaps nolines noobs 		///
		fragment tex nomtitles nobaselevels collabels(none) coeflabel(enroll_mm "Observations")
